function out = BalcoScaling(sample,t_step,mt)

% BalcoScaling generates time-dependent scaling factors. Letter codes 
% De, Du, Li, and St refer to scaling schemes of Desilets et al. (2006),
% Dunai (2001), Lifton (2006) and Stone (2000) respectively. The final 
% letter code Lm refers to the paleomagnetically corrected version of 
% the Lal 1991/Stone 2000 scaling factors.
%
% The code is a compilation of the functions make_al_be_consts_v22.m and 
% get_al_be_age.m. Compiled by Dmitry Tikhomirov, 2014.

% Originally  
% Written by Greg Balco -- UW Cosmogenic Nuclide Lab
% balcs@u.washington.edu
% April, 2007
% Part of the CRONUS-Earth online calculators: 
%      http://hess.ess.washington.edu/math
%
% Copyright 2001-2007, University of Washington
% All rights reserved
% Developed in part with funding from the National Science Foundation.
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License, version 2,
% as published by the Free Software Foundation (www.fsf.org).


%--------------------make_al_be_consts_v22.m-------------------------------

% Load the magnetic field data
load PMag_Mar07
% Relative dipole moment and time vector
consts.M = MM0; 
consts.t_M = t_M; 
% These start at 7500 yr -- time slices are 7500,8500,9500,10500,11500
% in order to use data from Yang et al; subsequent time slices are 
% 12000:1000:800000 for SINT800 data; final two time points are 801000
% and Inf. 

% Cutoff rigidity blocks for past 6900 yr. 
% TTRc and IHRC are lon x lat x time blocks of Rc values for the past 
% 6900 years.
% Both are derived by Nat Lifton from the magnetic field reconstructions of
% Korte and Constable. 
% TTRC has cutoff rigidity obtained by trajectory tracing -- these are for
% the Lifton and Desilets scaling factors. IHRc has cutoff rigidity
% obtained by finding magnetic inclination and horizontal field strength
% from the field model, then applying Equation 2 of Dunai(2001). 
consts.TTRc = TTRc; % data block
consts.IHRc = IHRc; % data block
consts.lat_Rc = lat_Rc; % lat and lon indices for Rc data block
consts.lon_Rc = lon_Rc;
consts.t_Rc = t_Rc; % time vector for Rc data block

% Effective pole positions and field strengths inferred from K and C field
% reconstructions for last 7000 yr. These are used in the
% paleomagnetically-corrected implementation of the Lal SF. They are for
% the same times as the RC slices in the data block above. Again,
% generated by Nat Lifton -- hence KCL = Korte-Constable-Lifton. 

consts.MM0_KCL = MM0_KCL;
consts.lat_pp_KCL = lat_pp_KCL;
consts.lon_pp_KCL = lon_pp_KCL;

% Solar variability from Lifton et al. 2005
% Has been averaged and resampled to the same time slices as everything
% else. 

consts.S = S; 
consts.SInf = 0.95; % Long-term mean S value;

%--------------------------------end---------------------------------------


%--------------------------get_al_be_age.m---------------------------------

% 3. Generate the paleo-rigidity record. 
% This isn't very general...requires particular time steps to take account 
% of how the paleomagnetic data is reported.

% catch for negative longitudes before Rc interpolation
if sample.long < 0; sample.long = sample.long + 360;end;

% Make the time domain for the forward age calculation. The time steps 
% follow the paleomagnetic data:
%
% 1. [0:500:6500 6900] to match Nat's K and C field derivatives
% The nominal pole positions have been resampled to these times,
% as has the solar modulation factor. 
%
% 2. [7500:1000:11500] to match Yang et al. 2000. 
% Assuming axial dipole at this point, so no pole positions,
% but solar modulation again resampled at [7500:1000:10500].
%
% 3. [12000:1000:800000] to match SINT800
%
% 4. logspace(log10(810000),7,200) gives 200 log-spaced points out
% to 10M. 99% saturation is 9.968 Myr for Be-10, 4.685 Myr for Al-26
%
% Result: 1009 elements. 
%
% Make the time vector
tv = [0:500:6500 6900 7500:1000:11500 12000:1000:800000 logspace(log10(810000),7,200)];

% correct mt
mt(mt < 12000) = 12000;

% now chop off tv;
clipindex = find(tv <= mt, 1, 'last' );
tv = tv(1:clipindex);

% interpolate an M for tv > 7000...
temp_M = interp1(consts.t_M,consts.M,tv(16:end));

% Make up the Rc vectors.
% Start with Lifton et al. 2005
% First 15 from the data blocks
LiRc = zeros(size(tv));
[lonRc,latRc,tRc] = meshgrid(consts.lon_Rc,consts.lat_Rc,consts.t_Rc);
[sam_lon,sam_lat,sam_tv] = meshgrid(sample.long,sample.lat,tv(1:15));
LiRc(1:15) = interp3(lonRc,latRc,tRc,consts.TTRc,sam_lon,sam_lat,sam_tv);
% The rest using Equation 6 of Lifton et al. 2005
LiRc(16:end) = 15.765.*temp_M.*((cos(abs(d2r(sample.lat)))).^3.8);

% Next, Desilets et al. 2006
DeRc = LiRc; % Beginning is the same;
% apply Desilets and Zreda 2003 Equation 19
% Note that latitude has to be clipped at 55 for this to work. 
DeLat = min([abs(sample.lat) 55]);
ee = [-4.3077e-3 2.4352e-2 -4.6757e-3 3.3287e-4 -1.0993e-5 1.7037e-7 -1.0043e-9];
ff = [1.4792e1 -6.6799e-2 3.5714e-3 2.8005e-5 -2.3902e-5 6.6179e-7 -5.0283e-9];

DeRc(16:end) = (ee(1)+ff(1).*temp_M) + ...
                (ee(2)+ff(2).*temp_M).*(DeLat.^1) + ...
                (ee(3)+ff(3).*temp_M).*(DeLat.^2) + ...
                (ee(4)+ff(4).*temp_M).*(DeLat.^3) + ...
                (ee(5)+ff(5).*temp_M).*(DeLat.^4) + ...
                (ee(6)+ff(6).*temp_M).*(DeLat.^5) + ...
                (ee(7)+ff(7).*temp_M).*(DeLat.^6);
  
% Next, Dunai 2001
% First 15 from the IH data block
DuRc = zeros(size(tv));
DuRc(1:15) = interp3(lonRc,latRc,tRc,consts.IHRc,sam_lon,sam_lat,sam_tv);
% The rest from Dunai 2001 equation 1
DuRc(16:end) = 14.9.*temp_M.*((cos(abs(d2r(sample.lat)))).^4);

% Finally, paleomagnetically-corrected Lal
% Same as Dunai > 7 ka
LmRc = DuRc;
% Approximate paleo-pole-positions and field strengths from KC for < 7 ka
LmLat = abs(90-angdist(sample.lat,sample.long,consts.lat_pp_KCL,consts.lon_pp_KCL));
LmRc(1:15) = 14.9.*(consts.MM0_KCL').*((cos(abs(d2r(LmLat)))).^4);              
                
% Also need solar modulation for Lifton SF's
this_S = zeros(size(LiRc)) + consts.SInf;
this_S(1:19) = consts.S;

% 4. Do the age calculation. Interestingly, because all of the P(t)
% functions are defined piecewise constant, it's not necessary to have
% a zero-finding loop. We can just calculate the cumulative integral and
% reverse-interpolate. 

% Calculate the unweighted P(t) separately to be sent back in the results.
% This is the surface production rate taking account of thickness. 
% P_St is already calculated
S_De = desilets2006sp(sample.pressure,DeRc);
S_Du = dunai2001sp(sample.pressure,DuRc);
S_Li = lifton2006sp(sample.pressure,LiRc,this_S);
S_Lm = stone2000Rcsp(sample.pressure,LmRc);
S_St = stone2000(sample.lat,sample.pressure,1);

%------------------------------end-----------------------------------------

% form output
out.time_scale = 0:t_step:mt;
out.Sc_De = interp1(tv,S_De,out.time_scale);
out.Sc_Du = interp1(tv,S_Du,out.time_scale);
out.Sc_Li = interp1(tv,S_Li,out.time_scale);
out.Sc_Lm = interp1(tv,S_Lm,out.time_scale);
out.Sc_St = S_St*ones(1,length(out.time_scale));

end