 function DB = DBmaker(t_step,t_lim,h_step,d_step,hscarp_step,mesh_unit,...
                       tot_slip,max_coll_lev_corr,tot_er,...
                       altitude,latitude,longitude,std_ant,tp_table,tp_type,...
                       azimuth,alpha,beta,gamma,scarp_height,rho_r,rho_c,...
                       s_cov,rho_s,s_month,...
                       sample_name,sample_top,sample_bot,sample_thick,...
                       sample_ch,sample_ch_err,coll_ch,wat_perc_rock,wat_perc_coll,...
                       sample_36Clconc,sample_36Clerr,...
                       andm,lambda,lambda_type)

% DB = DBmaker(t_step,t_lim,h_step,d_step,hscarp_step,mesh_unit,...
%              tot_slip,max_coll_lev_corr,tot_er,...
%              altitude,latitude,longitude,std_ant,tp_table,tp_type,...
%              azimuth,alpha,beta,gamma,scarp_height,rho_r,rho_c,...
%              s_cov,rho_s,s_month,...
%              sample_name,sample_top,sample_bot,sample_thick,...
%              sample_ch,sample_ch_err,coll_ch,wat_perc_rock,wat_perc_coll,...
%              sample_36Clconc,sample_36Clerr,...
%              andm,lambda,lambda_type) 
% creates a structure DB, which contains shielding factors and particle
% fluxes calculated at nodes of 3-dimentional mesh (the scarp height, 
% the position along the scarp height and the depth perpendicular to scarp 
% surface), as well as sample coefficients and scaling factors
% 
%
% DBmaker.m requires following input parameters: 
% Input parameters:
% t_step - time mesh spacing, yr (scalar)
% t_lim - maximal exposure age that can be reconstructed with
% a database, yr (scalar)
% h_step - mesh size of the position along scarp height, cm (scalar) 
% d_step - mesh size of the depth perpendicular to scarp
% surface, cm (scalar)
% hscarp_step - the mesh size of the scarp hight, cm (scalar)
% mesh_unit - mesh size along azimuth and inclination of sky
% hemisphere for muon flux calculation, degree (scalar)
% tot_slip - maximal total slip that can be reconstructed with
% a database, cm (scalar)
% max_coll_lev_corr - error of the reference point position, cm (scalar)
% tot_er - maximal depth of rock layer that can be eroded through a
% reconstructed fault scarp history, cm (scalar)
% altitude - altitude of the sampling site, m (scalar)
% latitude - latitude of the sampling site, m (scalar)
% longitude - longitude of the sampling site, m (scalar)
% std_ant - parameter that defines the convertion of the altitude to
% the preasure. 'std' - standard atmosphere. 'ant' - antarctic atmosphere.
% tp two columns matrix that should describe a horizon line as bars when 
% tp_type = 0; or two columns matrix that should describe a horizon line 
% as broken-line when tp_type = 1. In the case of bars approximation, 
% the first column is azimuths, between which a horizon line has equal 
% inclination, and the second column is inclinations of bars. In the case 
% of broken-line approximation, the first column is azimuths of broken-line 
% vertexes and the second column is inclinations of broken-line vertexes.
% azimuth - dip direction of fault scarp, degree (scalar)
% alpha  dip of coluvium wedge, degrees (scalar)
% beta  dip of fault scarp surface, degrees (scalar)
% gamma  dip ot fault scarp top, degrees (scalar)
% scarp_height - height of fault scarp measured along the scarp 
% surface, m (scalar)
% rho_r  average density of footwall rock, g/cm3 (scalar)
% rho_c  average density of colluvium wedge, g/cm3 (scalar)
% s_cov  depth of snow cover, cm (scalar)
% rho_s  average density of snow cover, g/cm3 (scalar)
% s_month - duration of the winter season, month (scalar)
% sample_name - 1-by-n cell vector of sample names where n is the number 
% of samples
% sample_top - 1-by-n vector of positions of sample top, cm
% sample_bot - 1-by-n vector of positions of sample bottom , cm
% sample_thick - 1-by-n vector of sample thicknesses, cm
% sample_ch - 18-by-n matrix containing chemical composition of each sample
% in following collumn order: Cl, C, O, Na, Mg, Al, Si, P, K, Ca Ti, Mg,
% Fe, B, Sm, Gd, U, Th, mass %
% sample_ch_err - 5-by-n matrix containing measurment errors of Cl, K, Ca,
% Ti and Fe, mass %
% coll_ch - 18-by-1 vector containing chemical composition of colluvium in
% the same element order as sample_ch, mass %
% wat_perc_rock - average content of water in footwall rock, mass %
% (scalar)
% wat_perc_coll - average content of water in colluvium wedge, mass
% % (scalar)
% sample_36Clconc - 1-by-n vector of 36Cl concentrations in samples, 
% 1e5 atoms Cl36/g rock 
% sample_36Clerr - 1-by-n vector of 1-sigma measurement errors of 36Cl 
% concentration in sample, 1e5 atoms Cl36/g rock
% andm - angle distribution parameter of high-energy neutrons, (scalar)
% lambda  attenuation length of high-energy neutrons, g/cm2 (scalar)
% lambda_type  parameter that defines type of high-energy neutron 
% attenuation length: apparent attenuation length when lambda_type = 0;   
% true particle attenuation length when lambda_type = 1

% Written by Dmitry Tikhomirov
% Institut fuer Geologie, Universitt Bern
% tikhomirov@geo.unibe.ch, tikhomirovdmitry@gmail.com
% 2013-2016
%
% This program is free software; you can redistribute it and/or modify it 
% under a Creative Commons Attribution-NonCommercial-ShareAlike 3.0 
% Unported License (http://creativecommons.org/licenses/by-nc-sa/3.0/)


% load nuclear physical constants and factors
load nucl_data;

% convert altitude to pressure
if (strcmp(std_ant,'std'))
        press = NCEPatm_2(latitude,longitude,altitude);
elseif (strcmp(std_ant,'ant'))
        press = antatm(altitude);
end;

% calculate scaling factors
site.pressure = press;
site.lat = latitude;
site.long = longitude;
DB = BalcoScaling(site,t_step,t_lim);

% store input parameters to the structure DB
DB.t_step = t_step;
DB.t_lim = t_lim;
% DB.h_step = h_step; % will be saved later, cause it could be corrected
DB.d_step = d_step;
% DB.hscarp_step = hscarp_step; % will be saved later, cause it could be corrected
DB.mesh_unit = mesh_unit;

DB.alpha = alpha;
DB.beta = beta;
DB.gamma = gamma;
DB.scarp_height = scarp_height;
DB.rho_r = rho_r;
DB.rho_c = rho_c;

DB.s_cov = s_cov;
DB.rho_s = rho_s;
DB.s_month = s_month;

DB.coll_ch = coll_ch;
DB.wat_perc_rock = wat_perc_rock;
DB.wat_perc_coll = wat_perc_coll;

DB.tot_slip = tot_slip;
DB.max_coll_lev_corr = max_coll_lev_corr;
DB.tot_er = tot_er;

DB.altitude = altitude;
DB.latitude = latitude;
DB.longitude = longitude;
DB.azimuth = azimuth;
DB.std_ant = std_ant;
DB.tp_type = tp_type;
DB.tp_table = tp_table;

DB.andm = andm;
DB.lambda = lambda;

% store sample names sizes and 36Cl data
DB.sam_name = sample_name;
DB.sam_bot = sample_bot;
DB.sam_top = sample_top;
DB.sam_thick = sample_thick;
DB.sam_36Clconc = sample_36Clconc;
DB.sam_36Clerr = sample_36Clerr;
DB.sam_ch = sample_ch;

% calculate sample coefficients
% some constants
N_a = 0.6022; % Avogadro number *10^24 because cross-sections are in barns
fstar_K = 0.035; % probability of 39K(mu-,x)36Cl
fstar_Ca = 0.045; % probability of 40Ca(mu-,x)36Cl
m_perc_39K = 0.9326; % natural abundance of 39K
m_perc_40Ca = 0.9694; % natural abundance of 40Ca
at_m = nucl_data(:,1)'; % atomic mass
log_dec = nucl_data(:,2)'; % logarithmic energy decrement  
sigma_sc = nucl_data(:,3)'; % fast neutron elastic scatering cross-section
sigma_th = nucl_data(:,4)'; % thermal neutron absorbtion cross-section
I_a = nucl_data(:,5)'; % effective resonance integral
f_c = nucl_data(:,6)'; % negative muon capture probability relative to O
f_d = nucl_data(:,7)'; % probability that negative muon does not decay
f_n = nucl_data(:,8)'; % neutron yield per captured negative muon
S_UTh = nucl_data(:,9)'; % stoping power at 8 Mev
Y_U = nucl_data(:,10)'; % neutron yield
Y_Th = nucl_data(:,11)'; % neutron yield

% convert parent elements errors in to relative one
sam_Cl_rerr = sample_ch_err(:,1)./sample_ch(:,1);
sam_K_rerr = sample_ch_err(:,2)./sample_ch(:,9);
sam_Ca_rerr = sample_ch_err(:,3)./sample_ch(:,10);
sam_Ti_rerr = sample_ch_err(:,4)./sample_ch(:,11);
sam_Fe_rerr = sample_ch_err(:,5)./sample_ch(:,13);

% correct values if the element is absent
sam_Cl_rerr(isnan(sam_Cl_rerr)) = 0;
sam_K_rerr(isnan(sam_K_rerr)) = 0;
sam_Ca_rerr(isnan(sam_Ca_rerr)) = 0;
sam_Ti_rerr(isnan(sam_Ti_rerr)) = 0;
sam_Fe_rerr(isnan(sam_Fe_rerr)) = 0;

% normalize sample elemental content
num_sam = size(sample_ch,1);
m_sam = bsxfun(@rdivide,sample_ch,sum(sample_ch,2));
m_sam = [m_sam zeros(num_sam,3)];
N_sam = bsxfun(@rdivide,m_sam,at_m);

% average rock elemental content
m_rock = mean(m_sam,1);
m_wat = [0 0.889 zeros(1,16) 0.11 0 0];
m_rock = m_rock*(1 - wat_perc_rock*0.01) + m_wat*wat_perc_rock*0.01;
N_rock = m_rock./at_m;

% average colluvium elemental content
m_coll = [coll_ch/sum(coll_ch) 0 0 0];
m_coll = m_coll*(1 - wat_perc_coll*0.01) + m_wat*wat_perc_coll*0.01;

% sample coefficients for fast muons spallation
fm_alpha = 0.75;
sigma_zero = 1.4e-3/(190^fm_alpha);
sam_fm = sigma_zero*N_a*N_sam(:,10);
sam_fm_err = sam_fm.*sam_Ca_rerr;

% sample coefficients for negative muons capture
f_c_tot = bsxfun(@times,N_sam,f_c);
f_c_K_sam = f_c(9)*N_sam(:,9)./sum(f_c_tot,2);
f_c_Ca_sam = f_c(10)*N_sam(:,10)./sum(f_c_tot,2);
sam_nm_K = f_c_K_sam*f_d(9)*fstar_K*m_perc_39K;
sam_nm_K_err = sam_nm_K.*sam_K_rerr;
sam_nm_Ca = f_c_Ca_sam*f_d(10)*fstar_Ca*m_perc_40Ca;
sam_nm_Ca_err = sam_nm_Ca.*sam_Ca_rerr;
sam_nm = sam_nm_K + sam_nm_Ca;
sam_nm_err = sqrt(sam_nm_K_err.^2 + sam_nm_Ca_err.^2);

% sample coefficients for epithermal neutron capture
Sigma_sc_rock = sum(N_a*sigma_sc.*N_rock);
Ieff_rock = sum(N_a*I_a.*N_rock);
log_dec_rock = sum(log_dec.*sigma_sc.*N_rock)/sum(sigma_sc.*N_rock);
Sigma_eth_rock = log_dec_rock*(Ieff_rock + Sigma_sc_rock);
p_rock = exp(-Ieff_rock/(log_dec_rock*Sigma_sc_rock));
sam_eth = N_a*I_a(1)*N_sam(:,1)*Sigma_eth_rock*(1-p_rock)/Ieff_rock;
sam_eth_err = sam_eth.*sam_Cl_rerr;

% sample coefficients for thermal neutron capture
sam_th = N_a*sigma_th(1)*N_sam(:,1);
sam_th_err = sam_th.*sam_Cl_rerr;

% sample coefficients for capture of thermal neutron  from fast muons
n_fm = 4.8*1e-6;
sam_nfm = n_fm*sam_th;
sam_nfm_err = n_fm*sam_th_err;

% sample coefficients for capture of thermal neutron  from negative muons
n_nm_rock = sum(N_rock.*f_c.*f_d.*f_n)/sum(N_rock.*f_c);
sam_nnm = n_nm_rock*sam_th;
sam_nnm_err = n_nm_rock*sam_th_err;

% 36Cl production rate by capture of thermal neutron from U & Th decay

Pn_alpha = (sum(bsxfun(@times,m_sam,S_UTh.*Y_U),2).*m_sam(:,17) +...
            sum(bsxfun(@times,m_sam,S_UTh.*Y_Th),2).*m_sam(:,18)).*1e6./...
            sum(bsxfun(@times,m_sam,S_UTh),2);
Pn_sf = 0.429*m_sam(:,17)*1e6;
P_UTh = (Pn_alpha + Pn_sf).*sam_th;
P_UTh_err = (Pn_alpha + Pn_sf).*sam_th_err;

% store sample coeficients in DB
DB.sam_spCa = m_sam(:,10)';
DB.sam_spK = m_sam(:,9)';
DB.sam_spTi = m_sam(:,11)';
DB.sam_spFe = m_sam(:,13)';
DB.sam_fm = sam_fm';
DB.sam_nm = sam_nm';
DB.sam_eth = sam_eth';
DB.sam_th = sam_th';
DB.sam_nfm = sam_nfm';
DB.sam_nnm = sam_nnm';
DB.P_UTh = P_UTh';

% and their errors
DB.sam_spCa_err = (m_sam(:,10).*sam_Ca_rerr)';
DB.sam_spK_err = (m_sam(:,9).*sam_K_rerr)';
DB.sam_spTi_err = (m_sam(:,11).*sam_Ti_rerr)';
DB.sam_spFe_err = (m_sam(:,13).*sam_Fe_rerr)';
DB.sam_fm_err = sam_fm_err';
DB.sam_nm_err = sam_nm_err';
DB.sam_eth_err = sam_eth_err';
DB.sam_th_err = sam_th_err';
DB.sam_nfm_err = sam_nfm_err';
DB.sam_nnm_err = sam_nnm_err';
DB.P_UTh_err = P_UTh_err';
                   
% prepare data for shielding calculation                                         
% convert tp vectors to topo matrix
topo = TpToTopo(azimuth,tp_table,tp_type);

% flip matrix "topo" due to simetry of a fault scarp geometry,
% calculation is done in quater-sphere
topo_fold = (topo + flipud(topo))/2;
topo_fold(181:360,:) = [];

% turn lambda to real one if neccesary
if strcmp(lambda_type,'apparent') == 1
    lambda = lambda*(andm+2)/(andm+1);
elseif strcmp(lambda_type,'true') == 1
    
else
    error('Parameter lambda_type can be "apparent" or "true"')
end

% define DB grid

% check mesh size
h_step(h_step > hscarp_step) = hscarp_step/5;
stripe_top = round_from_zero(max(sample_top),h_step);
max_hscarp_step = min([(scarp_height-stripe_top) (stripe_top+max_coll_lev_corr)]);
hscarp_step(hscarp_step > max_hscarp_step) = max_hscarp_step;

if mod(hscarp_step,h_step) ~= 0
    hscarp_step = round_from_zero(hscarp_step,h_step) - h_step;
end

% define depth grid
dep = max(sample_thick) + tot_er;
dep = round_from_zero(dep,d_step);
n = dep/d_step + 1;
DB.d = 0:d_step:dep;
depth = DB.d;
Densd = DB.d.*rho_r;

% define scarp slip grid
delta_hscarp = round_from_zero(tot_slip + max_coll_lev_corr*2,hscarp_step);
l = delta_hscarp/hscarp_step + 1;
t_hscarp_temp = round_from_zero(scarp_height + max_coll_lev_corr,h_step);
b_hscarp = t_hscarp_temp - delta_hscarp;
b_hscarp(b_hscarp < 0) = 0;
t_hscarp = b_hscarp + delta_hscarp;
DB.hscarp = b_hscarp:hscarp_step:t_hscarp;

% define possition grid
%stripe_top = round_from_zero(max(sample_top),h_step); % see line 315
t_pos = stripe_top + hscarp_step;
m_top = t_pos/h_step;

stripe_bot = round_from_zero(min(sample_bot),h_step);
b_pos = stripe_bot - hscarp_step;
m_bot = b_pos/h_step;     

m = m_top - m_bot + 1;
DB.h = b_pos:h_step:t_pos;
DB.h = DB.h - scarp_height + t_hscarp;

% max & min values of h 
h_min = stripe_bot + b_hscarp - scarp_height;
h_max = stripe_top + t_hscarp - scarp_height;
nh = hscarp_step/h_step;

% chose calculation of shielding with winter season of without
if s_cov > 0
    s = 2;
    s_cov_two = [0 s_cov];
else
    s = 1;
    s_cov_two = s_cov;
end

% initialize DB matrixes for shielding
DB.S_sp = zeros(n,m,l,s);
DB.Rnm = zeros(n,m,l,s);
DB.relerr_Rnm = zeros(n,m,l,s);
DB.PhiEB = zeros(n,m,l,s);
DB.F_eth = zeros(n,m,l,s);
DB.F_th = zeros(n,m,l,s);
DB.relerr_sp_th = zeros(n,m,l,s);
% and temporal matrixes
S_sp = zeros(1,n);
Phi = zeros(1,n);
PhiEB = zeros(1,n);
F_eth = zeros(1,n);
F_th = zeros(1,n);
relerr_sp_th = zeros(1,n);

% convert entered degrees into radians
alpha = d2r(alpha);
beta = d2r(beta);
gamma = d2r(gamma);

% start parallel computation with default profile
poolobj = gcp('nocreate');
if isempty(poolobj)
    poolobj = parpool;
end

%initialize progress bar
wbar = waitbar(0,'Please wait...','Name','Starting calculation',...
               'CreateCancelBtn',...
               'setappdata(gcbf,''canceling'',1)');
wax = findobj(wbar, 'type','axes');
tax = get(wax,'title');
set(tax,'FontSize',9)
drawnow
setappdata(wbar,'canceling',0);
tic;
oppa = 1;

% calculate shielding DB
for e = 1:s
    
    for k = 1:l
        hscarp = DB.hscarp(k);
        % define position of strip
        h_ex = DB.h - t_hscarp + hscarp;
            
        for i = 1:m
            h = h_ex(i);
             if  h < h_min || h > h_max
                continue
             end 
        
            parfor j = 1:n
                d = depth(j);
            
                   % spallation shielding factors
                S_sp(j) = PointShield_sp(d,h,alpha,beta,gamma,hscarp,s_cov_two(e),rho_r,rho_c,rho_s,topo_fold,andm,lambda);
                   % muons flux(Phi) and beta*Phi*E^alpha (see Heisinger 2002a)
                Temp_mu_out = PointShield_mu(mesh_unit,d,h,alpha,beta,gamma,hscarp,s_cov_two(e),rho_r,rho_c,rho_s,topo_fold,press);     
                Phi(j) = Temp_mu_out(1);
                PhiEB(j) = Temp_mu_out(2);                        
            end
            % approximate muon flux along depth
            Phi_approx_const = fit1decay(Densd, Phi, 7777);
            lambda_mu = Phi_approx_const(1);
            relerr_Rnm = Phi_approx_const(2);
            
            
            f_mu_neg = 0.44; % fraction of negative muons 
            Rnm = f_mu_neg.*Phi./lambda_mu;
            
            % store to DB
            DB.S_sp(:,i,k,e) = S_sp;
            DB.Rnm(:,i,k,e) = Rnm;
            DB.relerr_Rnm(:,i,k,e) = relerr_Rnm*ones(1,length(Densd));
            DB.PhiEB(:,i,k,e) = PhiEB;
            
                  % thermal and epithermal shielded fluxes
            if h < 0
                parfor j = 1:n
                    d = depth(j);
                    
                    Temp_sp_th_out = PointShield_sp_th(d,h,alpha,beta,gamma,hscarp,s_cov_two(e),rho_r,rho_c,rho_s,topo_fold,andm,lambda);
                    Ssp_th = Temp_sp_th_out(1);
                    Lambda_f = Temp_sp_th_out(2);
                    relerr_sp_th(j) = Temp_sp_th_out(3);
                    Dep_coll = Temp_sp_th_out(4);
                    Dep_rock = Temp_sp_th_out(5);
                    Dep_all = Dep_coll + Dep_rock;
                    av_wat_perc = (Dep_rock*wat_perc_rock +Dep_coll*wat_perc_coll + s_cov_two(e)*rho_s*100)/(Dep_rock + Dep_coll + s_cov_two(e)*rho_s);          
                    EthTh_temp = ThermEpithermNeutronCoef(Lambda_f,[coll_ch 0 0 0],av_wat_perc,nucl_data);
                    Eth_coef = EthTh_temp(1:4);
                    Th_coef = EthTh_temp(5:10);    
                    F_eth(j) = Ssp_th.*fun2decay(Dep_all,Eth_coef);
                    F_th(j) = Ssp_th.*fun3decay(Dep_all,Th_coef);
                end
                     % store to DB
                DB.relerr_sp_th(:,i,k,e) = relerr_sp_th;     
                DB.F_eth(:,i,k,e) = F_eth;
                DB.F_th(:,i,k,e) = F_th;
            else    
                
                Temp_sp_th_out = PointShield_sp_th(dep,h,alpha,beta,gamma,hscarp,s_cov_two(e),rho_r,rho_c,rho_s,topo_fold,andm,lambda);
                Ssp_th = Temp_sp_th_out(1);
                Lambda_f = Temp_sp_th_out(2);
                relerr_sp_th = Temp_sp_th_out(3)*ones(1,length(Densd));
                EthTh_temp = ThermEpithermNeutronCoef(Lambda_f,m_rock,0,nucl_data);
                Eth_coef = EthTh_temp(1:4);
                Th_coef = EthTh_temp(5:10);
                F_eth = Ssp_th.*fun2decay(Densd,Eth_coef);
                F_th = Ssp_th.*fun3decay(Densd,Th_coef);
                   % store to DB
                DB.relerr_sp_th(:,i,k,e) = relerr_sp_th;
                DB.F_eth(:,i,k,e) = F_eth;
                DB.F_th(:,i,k,e) = F_th;
            end
            
            % Check for Cancel button press - loop 3
            if getappdata(wbar,'canceling')
                oppa = 0;
                break
            end
            
            progr = (i + (k-1)*m + (e-1)*m*l - nh)/(m*l*s - 2*nh);
            elap_time = toc;
            rem_time = elap_time*(1/progr - 1);
            waitbar(progr,wbar,...
                    ['Elapsed time: ' sec2hhmmss(elap_time) '    Remaining time: ' sec2hhmmss(rem_time)]);
            set(wbar,'Name',['Calculating...' num2str(floor(progr*100)) '%']);
        end
        % Check for Cancel button press - loop 2
        if getappdata(wbar,'canceling')
            oppa = 0;
            break
        end
    end
    % Check for Cancel button press - loop 1
    if getappdata(wbar,'canceling')
        oppa = 0;
        break
    end
end

% finish parallel computation
delete(poolobj);

% close progress bar
delete(wbar)

DB.oppa = oppa;
if oppa == 0
    return
end

if s_cov > 0
    
    DB.S_sp(:,:,:,1) = DB.S_sp(:,:,:,1).*((12 - s_month)/12) + DB.S_sp(:,:,:,2).*(s_month/12);
    DB.Rnm(:,:,:,1) = DB.Rnm(:,:,:,1).*((12 - s_month)/12) + DB.Rnm(:,:,:,2).*(s_month/12);
    DB.relerr_Rnm(:,:,:,1) = DB.relerr_Rnm(:,:,:,1).*((12 - s_month)/12) + DB.relerr_Rnm(:,:,:,2).*(s_month/12);
    DB.PhiEB(:,:,:,1) = DB.PhiEB(:,:,:,1).*((12 - s_month)/12) + DB.PhiEB(:,:,:,2).*(s_month/12);
    DB.relerr_sp_th(:,:,:,1) = DB.relerr_sp_th(:,:,:,1).*((12 - s_month)/12) + DB.relerr_sp_th(:,:,:,2).*(s_month/12);
    DB.F_eth(:,:,:,1) = DB.F_eth(:,:,:,1).*((12 - s_month)/12) + DB.F_eth(:,:,:,2).*(s_month/12);
    DB.F_th(:,:,:,1) = DB.F_th(:,:,:,1).*((12 - s_month)/12) + DB.F_th(:,:,:,2).*(s_month/12);
    
    DB.S_sp(:,:,:,2) = [];
    DB.Rnm(:,:,:,2) = [];
    DB.relerr_Rnm(:,:,:,2) = [];
    DB.PhiEB(:,:,:,2) = [];
    DB.relerr_sp_th(:,:,:,2) = [];
    DB.F_eth(:,:,:,2) = [];
    DB.F_th(:,:,:,2) = [];
end

% store input parameters, which could be corrected or created, to the structure DB
DB.h_step = h_step;
DB.hscarp_step = hscarp_step;
DB.m_rock = m_rock;
DB.m_coll = m_coll;

end


