function out = Parameter_Window(res1,chi_res1,mean_res1,max_res1,min_res1,median_res1,mode_res1,...
                                      res2,chi_res2,mean_res2,max_res2,min_res2,median_res2,mode_res2,...
                                      chi,min_chi,win_type)
% creates a window containing statistics of modeled event or statistics of
% the begining of exposure and erosion rate

% Written by Dmitry Tikhomirov
% Institut fuer Geologie, Universitaet Bern
% tikhomirov@geo.unibe.ch, tikhomirovdmitry@gmail.com
% 2013-2016
%
% This program is free software; you can redistribute it and/or modify it 
% under a Creative Commons Attribution-NonCommercial-ShareAlike 3.0 
% Unported License (http://creativecommons.org/licenses/by-nc-sa/3.0/)


% define axes names
if win_type == 0
    window_name = 'Beginning_of_Exposure_and_Erosion_Rate';
    label1 = 'Beginning of exposure, yr';
    label2 = 'Erosion rate, cm/kyr';
    forma1 = '%.0f';
    forma2 = '%.3f';
    units2 = 'cm/kyr';
else
    window_name = ['Earthquake_' num2str(win_type)];
    label1 = 'Age of earthquake, yr';
    label2 = 'Colluvium position before earthquake, cm';
    forma1 = '%.0f';
    forma2 = '%.0f';
    units2 = 'cm';
end

% define graph limits for chi-squared
max_chi = max(chi);
if max_chi == min_chi
    if max_chi == 0
        chi_lims = [-0.1 0.1];
    else
        chi_lims = [0.9 1.1].*max_chi;
    end
else
    delta_chi_lims = (max_chi-min_chi)*0.05;
    chi_lims = [min_chi-delta_chi_lims max_chi+delta_chi_lims];
end

% define bins for result1
if min_res1 == max_res1
    if min_res1 == 0
        cent_res1 = -0.05:0.05:0.05;
    else
        cent_res1 = (0.95:0.05:1.05).*min_res1;
    end
else
    n_bin1 = calcnbins(res1,'fd');
    step_res1 = ((max_res1 - min_res1)/n_bin1);
    cent_res1 = (min_res1 + 0.5*step_res1):step_res1:(max_res1 - 0.5*step_res1);
end

% define bins for result2
if min_res2 == max_res2
    if min_res2 == 0
        cent_res2 = -0.05:0.05:0.05;
    else
        cent_res2 = (0.95:0.05:1.05).*min_res2;
    end
else
    n_bin2 = calcnbins(res2,'fd');
    step_res2 = ((max_res2 - min_res2)/n_bin2);
    cent_res2 = (min_res2 + 0.5*step_res2):step_res2:(max_res2 - 0.5*step_res2);
end

% define nubber of counts
f_res1 = hist(res1,cent_res1);
f_res2 = hist(res2,cent_res2);

delta_res1 = (max(cent_res1) - min(cent_res1))*0.1;
xl_res1 = [(min(cent_res1) - delta_res1) (max(cent_res1) + delta_res1)];
delta_res2 = (max(cent_res2) - min(cent_res2))*0.1;
xl_res2 = [(min(cent_res2) - delta_res2) (max(cent_res2) + delta_res2)];

% draw results
out = figure('Units','characters',...
             'Position', [50, 10, 173, 55],...
             'Name', window_name,...  
             'NumberTitle', 'off','Color',[0.941, 0.941, 0.941],... 
             'MenuBar', 'none','PaperPositionMode', 'auto');      

axes1 = axes('Units', 'characters','Position', [12 33 68 19]);
    hold on
    ylabel('Frequency')
    xlabel(label1)
    bar(cent_res1, f_res1, 'r', 'EdgeColor', 'r');
    plot(cent_res1,smooth(f_res1,7),'b','linewidth',2)
    xlim(xl_res1)
    ylim([0 Inf])
axes2 = axes('Units', 'characters','Position', [92 33 68 19]);
    hold on
    ylabel('Frequency')
    xlabel(label2)
    bar(cent_res2, f_res2, 'r', 'EdgeColor', 'r');
    plot(cent_res2,smooth(f_res2,7),'b','linewidth',2)
    xlim(xl_res2)
    ylim([0 Inf])       
axes3 = axes('Units', 'characters','Position', [12 10 68 19]);
    hold on
    ylabel('Chi-squared value')
    xlabel(label1)
    plot(res1, chi,'r','LineStyle','none','Marker','.','MarkerSize',3)
    plot(chi_res1, min_chi,'b','LineStyle','none','Marker','.','MarkerSize',5)
    xlim(xl_res1)
    ylim(chi_lims)
    grid on
axes4 = axes('Units', 'characters','Position', [92 10 68 19]);
    hold on
    ylabel('Chi-squared value')
    xlabel(label2)
    plot(res2, chi,'r','LineStyle','none','Marker','.','MarkerSize',3)
    plot(chi_res2, min_chi,'b','LineStyle','none','Marker','.','MarkerSize',5)
    xlim(xl_res2)
    ylim(chi_lims)
    grid on
    
uicontrol('Style','text','FontSize',10,'String',['min = ' num2str(min_res1,forma1) 'yr'],...
          'Units', 'characters','Position',[12 1 34 1.5]);
uicontrol('Style','text','FontSize',10,'String',['mean = ' num2str(mean_res1,forma1) 'yr'],...
          'Units', 'characters','Position',[12 2.5 34 1.5]);
uicontrol('Style','text','FontSize',10,'String',['chi = ' num2str(chi_res1,forma1) 'yr'],...
          'Units', 'characters','Position',[12 4 34 1.5]);
uicontrol('Style','text','FontSize',10,'String',['max = ' num2str(max_res1,forma1) 'yr'],...
          'Units', 'characters','Position',[46 1 34 1.5]);
uicontrol('Style','text','FontSize',10,'String',['median = ' num2str(median_res1,forma1) 'yr'],...
          'Units', 'characters','Position',[46 2.5 34 1.5]);
uicontrol('Style','text','FontSize',10,'String',['mode = ' num2str(mode_res1,forma1) 'yr'],...
          'Units', 'characters','Position',[46 4 34 1.5]);
uicontrol('Style','text','FontSize',10,'String',['min = ' num2str(min_res2,forma2) units2],...
          'Units', 'characters','Position',[92 1 34 1.5]);
uicontrol('Style','text','FontSize',10,'String',['mean = ' num2str(mean_res2,forma2) units2],...
          'Units', 'characters','Position',[92 2.5 34 1.5]);
uicontrol('Style','text','FontSize',10,'String',['chi = ' num2str(chi_res2,forma2) units2],...
          'Units', 'characters','Position',[92 4 34 1.5]);
uicontrol('Style','text','FontSize',10,'String',['max = ' num2str(max_res2,forma2) units2],...
          'Units', 'characters','Position',[126 1 34 1.5]);
uicontrol('Style','text','FontSize',10,'String',['median = ' num2str(median_res2,forma2) units2],...
          'Units', 'characters','Position',[126 2.5 34 1.5]);
uicontrol('Style','text','FontSize',10,'String',['mode = ' num2str(mode_res2,forma2) units2],...
          'Units', 'characters','Position',[126 4 34 1.5]);
      
 
slider1 = uicontrol('Style', 'slider', 'Min',0.005,'Max',1,'Value', 1,...
                    'Units', 'characters','Position', [164 10 5 42],...
                    'Callback', {@slider_callback,chi_lims,min_chi,axes3,axes4});
                
uicontrol('Style', 'pushbutton',...
          'Units', 'characters','Position', [3 1 10 2],...
          'FontSize',9,'String', 'Print',...
          'Callback', {@print_fig_callback,slider1});      
      
      
function slider_callback(hObject, eventdata,chi_lims,min_chi,axes3,axes4)

factor = get(hObject,'Value');
ylim(axes3,[(min_chi-(min_chi-chi_lims(1))*factor) (min_chi+(chi_lims(2)-min_chi)*factor)])
ylim(axes4,[(min_chi-(min_chi-chi_lims(1))*factor) (min_chi+(chi_lims(2)-min_chi)*factor)])

      
function print_fig_callback(hObject, eventdata, slider1)

set(hObject, 'Visible', 'Off');
set(slider1, 'Visible', 'Off');
[file,path]=uiputfile({'*.tif','TIFF image (*.tif)';...
                       '*.bmp','Bitmap file (*.bmp)';...
                       '*.ai','Adobe Illustrator file (*.ai)';...
                       '*.eps','EPS file (*.eps)';...
                       '*.emf','Enhanced metafile (*.emf)';...
                       '*.jpg','JPEG image (*.jpg)';...
                       '*.png','Portable Network Graphics File (*.png)';...
                       '*.fig','MATLAB Figure (*.fig)'},...
                       'Save Image As');
                   
% If "Cancel" is selected then return
if isequal([file,path],[0,0])
    set(hObject, 'Visible', 'on');
   	return
end

saveas(gcf,fullfile(path, file));
set(slider1, 'Visible', 'on');
set(hObject, 'Visible', 'on');
