function out = PointShield_mu(mesh_unit,d,h,alpha,beta,gamma,hscarp,s_cov,...
    rho_r,rho_c,rho_s,topo_fold,press)

% calculates flux of fast muons and function beta(h)*Phi(h)*<E(h)>^alpha 
% (Heisenger et al. 2002a) at the point of footwall defined by coordinates 
% (d,h). The results are scaled to local altitude defined through 
% atmospheric pressure.

% input:
% mesh_unit - mesh size of sky hemisphere grid, degree.
% d - depth perpendicular to scarp surface, cm.
% h - position along fault scarp height, cm. h is positive above colluvium 
% and negative below.
% alpha  dip of coluvium wedge, degree.
% beta  dip of fault scarp surface, degree.
% gamma  dip ot fault scarp top, degree.
% hscarp  height along fault scarp surface from colluvium to the top of 
% fault scarp, cm.
% s_cov  depth of snow cover, cm. The snow cover is assumed as 
% a uniform layer on colluvium and scarp top surface.
% rho_r  average density of foot wall rock, g/cm3.
% rho_c  average density of colluvium wedge, g/cm3.
% rho_s  average density of snow cover, g/cm3.
% topo - matrix containing topographic shielding (see TpToTopo.m for details)
% press - atmospheric preasure at the site of interest, hPa (mbar).

% Reference: 
% 1) Heisinger, B., Lal, D., Jull, A. J. T., Kubik, P., Ivy-Ochs, S., 
% Knie, K., & Nolte, E. (2002). Production of selected cosmogenic 
% radionuclides by muons: 2. Capture of negative muons Earth and Planetary 
% Science Letters, 200(3 - 4), 357 - 369

% 2) Tikhomirov, D., Ak?ar, N., Ivy-Ochs, S., Alfimov, V., & Schl?chter, C. 
% (2014). Calculation of shielding factors for production of cosmogenic 
% nuclides in fault scarps. Quaternary Geochronology, 19(0), 181-193.

% Written by Dmitry Tikhomirov
% Institut fuer Geologie, Universitt Bern
% tikhomirov@geo.unibe.ch, tikhomirovdmitry@gmail.com
% 2013-2016
%
% This program is free software; you can redistribute it and/or modify it 
% under a Creative Commons Attribution-NonCommercial-ShareAlike 3.0 
% Unported License (http://creativecommons.org/licenses/by-nc-sa/3.0/)


% change zero depth to avoid a singularity
d(d == 0) = 1e-6;

% correct grid spacing if needed
mesh_unit(mesh_unit > 6) = 6;
mesh_unit(mesh_unit == 4) = 3;

% define number of meshes in the grid
Nlin = 180/mesh_unit;
Ncol = 90/mesh_unit;

% define solid angle of one mesh
unit_angle = pi*pi/(Nlin*Ncol);

% recalculate topographic shilding according to new grid
topo_temp = zeros(Nlin,Ncol);

for l = 0:(Nlin - 1)
    for c = 0:(Ncol - 1)
        matr_temp = topo_fold((1 + mesh_unit*l):(mesh_unit*(l+1)),(1 + mesh_unit*c):(mesh_unit*(c+1)));
        topo_temp(l+1,c+1) = sum(matr_temp(:))/mesh_unit^2;
    end
end

topo_fold = topo_temp;

% create grid in spherical coordinates
[theta,phi] = meshgrid(1:Ncol,1:Nlin);
theta = (theta - 0.5)*mesh_unit;
phi = (phi - 0.5)*mesh_unit;
theta = theta*pi/180 ;
phi = phi*pi/180 ;

% "zero" is the function theta_zero(phi) (see the Tikhomirov et al. 2014)
zero = atan(tan(atan(d/h)-beta).*cos(phi));
% "top" is the function theta_top(phi) (see the Tikhomirov et al. 2014)
top = atan(tan(atan(d/(h-hscarp))-beta).*cos(phi));
% "gtop" is the function similar to theta_s(phi) (see the Tikhomirov et al. 2014)
gtop = atan(-tan(gamma).*cos(phi));

d_rock = d*rho_r;
d_top = (d*cos(beta-gamma) - (h-hscarp)*sin(beta-gamma))*rho_r + ...
    s_cov*rho_s;


h_min = -d*tan(beta);
h_plus = d/tan(beta);
h_max = hscarp - d*tan(beta);

if h <= h_min
    O_plus = zero;
    O_min = pi/2;
    T_plus = top;
    T_min = pi/2;
elseif (h > h_plus) && (h <= h_max)
    O_plus = pi/2;
    O_min = 0;
    T_plus = top;
    T_min = pi/2;
elseif h > h_max
    O_plus = pi/2;
    O_min = 0;
    T_plus = pi/2;
    T_min = top;
elseif (h > h_min) && (h <= h_plus)
    O_plus = pi/2;
    O_min = zero;
    T_plus = top;
    T_min = pi/2;
end



dd1 = colluvium(phi,theta,alpha,beta,d,h,s_cov,rho_r,rho_c,rho_s).*(theta < O_min).*(phi < pi/2);
if sum(dd1(:)) == 0
    phi_mu1 = zeros(Nlin,Ncol);
    beta_ebar1 = zeros(Nlin,Ncol);
else    
    phi_mu1 = muon_flux(theta,dd1,press,mesh_unit).*(theta < O_min).*(phi < pi/2);
    beta_ebar1 = beta_ebar(theta,dd1).*(theta < O_min).*(phi < pi/2);
end

dd2 = d_rock.*ugol(phi,theta,beta).*(theta >= O_min).*(theta < T_min).*(phi < pi/2);
if sum(dd2(:)) == 0
    phi_mu2 = zeros(Nlin,Ncol);
    beta_ebar2 = zeros(Nlin,Ncol);
else    
    phi_mu2 = muon_flux(theta,dd2,press,mesh_unit).*(theta >= O_min).*(theta < T_min).*(phi < pi/2);
    beta_ebar2 = beta_ebar(theta,dd2).*(theta >= O_min).*(theta < T_min).*(phi < pi/2);
end

dd3 = d_top.*ugol(phi,theta,gamma).*(theta >= T_min).*(phi < pi/2);
if sum(dd3(:)) == 0
    phi_mu3 = zeros(Nlin,Ncol);
    beta_ebar3 = zeros(Nlin,Ncol);
else    
    phi_mu3 = muon_flux(theta,dd3,press,mesh_unit).*(theta >= T_min).*(phi < pi/2);
    beta_ebar3 = beta_ebar(theta,dd3).*(theta >= T_min).*(phi < pi/2);
end

dd4 = colluvium(phi,theta,alpha,beta,d,h,s_cov,rho_r,rho_c,rho_s).*(theta > O_plus).*(phi > pi/2);
if sum(dd4(:)) == 0
    phi_mu4 = zeros(Nlin,Ncol);
    beta_ebar4 = zeros(Nlin,Ncol);
else    
    phi_mu4 = muon_flux(theta,dd4,press,mesh_unit).*(theta > O_plus).*(phi > pi/2);
    beta_ebar4 = beta_ebar(theta,dd4).*(theta > O_plus).*(phi > pi/2);
end

dd5 = d_rock.*ugol(phi,theta,beta).*(theta > T_plus).*(theta <= O_plus).*(phi > pi/2);
if sum(dd5(:)) == 0
    phi5 = zeros(Nlin,Ncol);
    beta_ebar5 = zeros(Nlin,Ncol);
else    
    phi5 = muon_flux(theta,dd5,press,mesh_unit).*(theta > T_plus).*(theta <= O_plus).*(phi > pi/2);
    beta_ebar5 = beta_ebar(theta,dd5).*(theta > T_plus).*(theta <= O_plus).*(phi > pi/2);
end

dd6 = d_top.*ugol(phi,theta,gamma).*(theta >= gtop).*(theta <= T_plus).*(phi > pi/2);
if sum(dd6(:)) == 0
    phi_mu6 = zeros(Nlin,Ncol);
    beta_ebar6 = zeros(Nlin,Ncol);
else    
    phi_mu6 = muon_flux(theta,dd6,press,mesh_unit).*(theta >= gtop).*(theta <= T_plus).*(phi > pi/2);
    beta_ebar6 = beta_ebar(theta,dd6).*(theta >= gtop).*(theta <= T_plus).*(phi > pi/2);
end

phi_mu = (phi_mu1 + phi_mu2 + phi_mu3 + phi_mu4 + phi5 + phi_mu6).*topo_fold.*unit_angle;
Phi_mu = sum(phi_mu(:));

Beta_ebar = (beta_ebar1 + beta_ebar2 + beta_ebar3 + beta_ebar4 + beta_ebar5 + beta_ebar6);

phiBE = phi_mu.*Beta_ebar;
PhiBE = sum(phiBE(:));

out = [Phi_mu PhiBE];
end
