function out = PointShield_sp(d,h,alpha,beta,gamma,hscarp,s_cov,...
    rho_r,rho_c,rho_s,topo_fold,m,lambda)

% calculates shielding factor for spallation by high-energy neutrons 
% at the point of footwall defined by coordinates (d,h)

% input:
% d - depth perpendicular to scarp surface, cm.
% h - position along fault scarp height, cm. h is positive above colluvium 
% and negative below.
% alpha  dip of coluvium wedge, degree.
% beta  dip of fault scarp surface, degree.
% gamma  dip ot fault scarp top, degree.
% hscarp  height along fault scarp surface from colluvium to the top of 
% fault scarp, cm.
% s_cov  depth of snow cover, cm. The snow cover is assumed as 
% a uniform layer on colluvium and scarp top surface.
% rho_r  average density of foot wall rock, g/cm3.
% rho_c  average density of colluvium wedge, g/cm3.
% rho_s  average density of snow cover, g/cm3.
% topo - matrix containing topographic shielding (see TpToTopo.m for details)
% m  angle distribution parameter of high-energy neutrons.
% lambda  true particle attenuation length of high-energy neutrons.

% Reference:
% Tikhomirov, D., Akcar, N., Ivy-Ochs, S., Alfimov, V., & Schl?chter, C. 
% (2014). Calculation of shielding factors for production of cosmogenic 
% nuclides in fault scarps. Quaternary Geochronology, 19(0), 181-193.

% Written by Dmitry Tikhomirov
% Institut fuer Geologie, Universitt Bern
% tikhomirov@geo.unibe.ch, tikhomirovdmitry@gmail.com
% 2013-2016
%
% This program is free software; you can redistribute it and/or modify it 
% under a Creative Commons Attribution-NonCommercial-ShareAlike 3.0 
% Unported License (http://creativecommons.org/licenses/by-nc-sa/3.0/)

% change zero depth to avoid a singularity
d(d == 0) = 1e-6;

% create grid in spherical coordinates
[theta,phi] = meshgrid(0:89,0:179);
theta = theta + 0.5;
phi = phi + 0.5;
theta = theta*pi/180;
phi = phi*pi/180;

% "zero" is the function theta_zero(phi) (see the Tikhomirov et al. 2014)
zero = atan(tan(atan(d/h)-beta).*cos(phi));
% "top" is the function theta_top(phi) (see the Tikhomirov et al. 2014)
top = atan(tan(atan(d/(h-hscarp))-beta).*cos(phi));
% "gtop" is the function similar to theta_s(phi) (see the Tikhomirov et al. 2014)
gtop = atan(-tan(gamma).*cos(phi));

% depth density for footwall
d_rock = d*rho_r;
% depth density for scarp top
d_top = (d*cos(beta-gamma) - (h-hscarp)*sin(beta-gamma))*rho_r + ...
    s_cov*rho_s;


h_min = -d*tan(beta);
h_plus = d/tan(beta);
h_max = hscarp - d*tan(beta);

if h <= h_min
    O_plus = zero;
    O_min = pi/2;
    T_plus = top;
    T_min = pi/2;
elseif (h > h_plus) && (h <= h_max)
    O_plus = pi/2;
    O_min = 0;
    T_plus = top;
    T_min = pi/2;
elseif h > h_max
    O_plus = pi/2;
    O_min = 0;
    T_plus = pi/2;
    T_min = top;
elseif (h > h_min) && (h <= h_plus)
    O_plus = pi/2;
    O_min = zero;
    T_plus = top;
    T_min = pi/2;
end

d1 = colluvium(phi,theta,alpha,beta,d,h,s_cov,rho_r,rho_c,rho_s).*(theta < O_min).*(phi < pi/2);
S1 = spall(theta,d1,m,lambda).*(theta < O_min).*(phi < pi/2);

d2 = d_rock.*ugol(phi,theta,beta).*(theta >= O_min).*(theta < T_min).*(phi < pi/2);
S2 = spall(theta,d2,m,lambda).*(theta >= O_min).*(theta < T_min).*(phi < pi/2);

d3 = d_top.*ugol(phi,theta,gamma).*(theta >= T_min).*(phi < pi/2);
S3 = spall(theta,d3,m,lambda).*(theta >= T_min).*(phi < pi/2);

d4 = colluvium(phi,theta,alpha,beta,d,h,s_cov,rho_r,rho_c,rho_s).*(theta > O_plus).*(phi > pi/2);
S4 = spall(theta,d4,m,lambda).*(theta > O_plus).*(phi > pi/2);

d5 = d_rock.*ugol(phi,theta,beta).*(theta > T_plus).*(theta <= O_plus).*(phi > pi/2);
S5 = spall(theta,d5,m,lambda).*(theta > T_plus).*(theta <= O_plus).*(phi > pi/2);

d6 = d_top.*ugol(phi,theta,gamma).*(theta >= gtop).*(theta <= T_plus).*(phi > pi/2);
S6 = spall(theta,d6,m,lambda).*(theta >= gtop).*(theta <= T_plus).*(phi > pi/2);

S = (S1 + S2 + S3 + S4 + S5 + S6).*topo_fold;

Sfull = ((sin(theta)).^m).*cos(theta);

out = sum(S(:))/sum(Sfull(:));

end
