function out = PointShield_sp_coll(d,h,alpha,beta,gamma,hscarp,s_cov,...
    rho_r,rho_s,topo_fold,m,lambda)

% calculates shielding factor for spallation by high-energy neutrons at a 
% point of interest on colluvium or footwall surface. The point of interest 
% is defined by perpendicular to respective surface from point (d,h)

% input:
% d - depth perpendicular to scarp surface, cm.
% h - position along fault scarp height, cm. h is positive above colluvium 
% and negative below.
% alpha  dip of coluvium wedge, degree.
% beta  dip of fault scarp surface, degree.
% gamma  dip ot fault scarp top, degree.
% hscarp  height along fault scarp surface from colluvium to the top of 
% fault scarp, cm.
% s_cov  depth of snow cover, cm. The snow cover is assumed as 
% a uniform layer on colluvium and scarp top surface.
% rho_r  average density of foot wall rock, g/cm3.
% rho_c  average density of colluvium wedge, g/cm3.
% rho_s  average density of snow cover, g/cm3.
% topo - matrix containing topographic shielding (see TpToTopo.m for details)
% m  angle distribution parameter of high-energy neutrons.
% lambda  true particle attenuation length of high-energy neutrons.

% Written by Dmitry Tikhomirov
% Institut fuer Geologie, Universitat Bern
% tikhomirov@geo.unibe.ch, tikhomirovdmitry@gmail.com
% 2013-2016
%
% This program is free software; you can redistribute it and/or modify it 
% under a Creative Commons Attribution-NonCommercial-ShareAlike 3.0 
% Unported License (http://creativecommons.org/licenses/by-nc-sa/3.0/)

% change zero depth to avoid a singularity
d(d == 0) = 1e-6;

% create grid in spherical coordinates
[theta,phi] = meshgrid(0:89,0:179);
theta = theta + 0.5;
phi = phi + 0.5;
theta = theta*pi/180;
phi = phi*pi/180;

h_min = - d*tan(beta - alpha);


if h < h_min
    h_c = (-h)*cos(beta - alpha) - d*sin(beta - alpha); % projection on colluvium surface
    CT = sqrt(hscarp^2 + h_c^2 + 2*hscarp*h_c*cos(beta-alpha)); % distance from the point on colluvium to the top of footwall
    theta_top = asin(hscarp*sin(beta-alpha)/CT)+alpha; %direction to the top of footwall from the point on colluvium

    CW = CT*sin(theta_top - gamma); % distance from the point on colluvium to scarp top surface
    CZ = h_c*sin(beta - alpha); % distance from the point on colluvium to footwall surface

    top = atan(-tan(theta_top).*cos(phi));
elseif h_min <= h < 0
    CW = (hscarp - h + h_min)*sin(beta - gamma);
    CZ = 0;
    
    top = atan(-tan(beta).*cos(phi));
else
    CW = (hscarp - h)*sin(beta - gamma);
    CZ = 0;
    
    top = atan(-tan(beta).*cos(phi));
end    
    gtop = atan(-tan(gamma).*cos(phi));

S1 = sky(theta,m).*(phi < pi/2);

S2 = sky(theta,m).*(theta >= top).*(phi > pi/2);

d3 = ((CW.*rho_r + s_cov.*rho_s).*ugol(phi,theta,gamma) - (CZ.*rho_r).*ugol(phi,theta,(pi - beta))).*(theta < top).*(theta >= gtop).*(phi > pi/2);
S3 = ((sin(theta)).^m).*exp(-d3/lambda).*cos(theta).*(theta < top).*(theta >= gtop).*(phi > pi/2);

S = (S1 + S2 + S3).*topo_fold;

Sfull = sky(theta,m);

out = sum(S(:))/sum(Sfull(:));

end

