function out = PointShield_sp_th(d,h,alpha,beta,gamma,hscarp,s_cov,...
    rho_r,rho_c,rho_s,topo_fold,m,lambda)

% calculates shielding factor and attenuation length of high energy
% neutrons in direction of point (d,h) from upper surfase (colluvium 
% surface or scarp surface)
% out  = [shielding_factor  attenuation_length  depth_through_colluvium  depth_through_rock]

% input:
% d - depth perpendicular to scarp surface, cm.
% h - position along fault scarp height, cm. h is positive above colluvium 
% and negative below.
% alpha  dip of coluvium wedge, degree.
% beta  dip of fault scarp surface, degree.
% gamma  dip ot fault scarp top, degree.
% hscarp  height along fault scarp surface from colluvium to the top of 
% fault scarp, cm.
% s_cov  depth of snow cover, cm. The snow cover is assumed as 
% a uniform layer on colluvium and scarp top surface.
% rho_r  average density of foot wall rock, g/cm3.
% rho_c  average density of colluvium wedge, g/cm3.
% rho_s  average density of snow cover, g/cm3.
% topo - matrix containing topographic shielding (see TpToTopo.m for details)
% m  angle distribution parameter of high-energy neutrons.
% lambda  true particle attenuation length of high-energy neutrons.

% Written by Dmitry Tikhomirov
% Institut fuer Geologie, Universitt Bern
% tikhomirov@geo.unibe.ch, tikhomirovdmitry@gmail.com
% 2013-2016
%
%
% This program is free software; you can redistribute it and/or modify it 
% under a Creative Commons Attribution-NonCommercial-ShareAlike 3.0 
% Unported License (http://creativecommons.org/licenses/by-nc-sa/3.0/)

h_min = - d*tan(beta-alpha);

    % points: down - the point of interest with coordinates (h,d)
    %         surf - the point at the perpendicular to upper surfase (colluvium 
    %                surface or scarp surface) from the point of interest
    %         mid - if h < 2*h_min   
    %                   the point on the surface of footwall
    %               else
    %                   the point in the middle of points down and surf
    %               end
     
if h < 2*h_min
    S_surf = PointShield_sp_coll(d,h,alpha,beta,gamma,hscarp,s_cov,rho_r,rho_s,topo_fold,m,lambda);
    S_mid = PointShield_sp(0,h - h_min,alpha,beta,gamma,hscarp,s_cov,rho_r,rho_c,rho_s,topo_fold,m,lambda);
    S_down = PointShield_sp(d,h,alpha,beta,gamma,hscarp,s_cov,rho_r,rho_c,rho_s,topo_fold,m,lambda);
    Dep_coll = (-h + h_min)*sin(beta-alpha)*rho_c + s_cov*rho_s;
    Dep_rock = d*rho_r/cos(beta-alpha);
    Dep_surf = 0;
    Dep_mid = Dep_coll;
    Dep_down = Dep_coll + Dep_rock;
    
elseif 2*h_min <= h < h_min
    S_surf = PointShield_sp_coll(d,h,alpha,beta,gamma,hscarp,s_cov,rho_r,rho_s,topo_fold,m,lambda);
    S_mid = PointShield_sp(d/2,h - h_min/2,alpha,beta,gamma,hscarp,s_cov,rho_r,rho_c,rho_s,topo_fold,m,lambda);
    S_down = PointShield_sp(d,h,alpha,beta,gamma,hscarp,s_cov,rho_r,rho_c,rho_s,topo_fold,m,lambda);
    Dep_coll = (-h + h_min)*sin(beta-alpha)*rho_c + s_cov*rho_s;
    Dep_rock = d*rho_r/cos(beta-alpha);
    Dep_surf = 0;
    Dep_mid = Dep_coll + Dep_rock/2;
    Dep_down = Dep_coll + Dep_rock;
    
elseif (h_min <= h) && (h < 0)
    S_surf = PointShield_sp_coll(0,0,alpha,beta,gamma,hscarp,s_cov,rho_r,rho_s,topo_fold,m,lambda);
    S_mid = PointShield_sp(d/2,h/2,alpha,beta,gamma,hscarp,s_cov,rho_r,rho_c,rho_s,topo_fold,m,lambda);
    S_down = PointShield_sp(d,h,alpha,beta,gamma,hscarp,s_cov,rho_r,rho_c,rho_s,topo_fold,m,lambda);
    Dep_coll = 0;
    Dep_rock = sqrt(d^2 + h^2)*rho_r;
    Dep_surf = 0;
    Dep_mid = Dep_rock/2;
    Dep_down = Dep_rock;
    
else
    S_surf = PointShield_sp(0,h,alpha,beta,gamma,hscarp,s_cov,rho_r,rho_c,rho_s,topo_fold,m,lambda);
    S_mid = PointShield_sp(d/2,h,alpha,beta,gamma,hscarp,s_cov,rho_r,rho_c,rho_s,topo_fold,m,lambda);
    S_down = PointShield_sp(d,h,alpha,beta,gamma,hscarp,s_cov,rho_r,rho_c,rho_s,topo_fold,m,lambda);
    Dep_coll = 0;
    Dep_rock = d*rho_r;
    Dep_surf = 0; 
    Dep_mid = Dep_rock/2;
    Dep_down = Dep_rock;
end

Ssp_th = [S_surf S_mid S_down];
Dep_th = [Dep_surf Dep_mid Dep_down];
out = [S_surf fit1decay(Dep_th ,Ssp_th, 1111) Dep_coll Dep_rock];

end


