function out = RandomWalkScarp(DB,Var_db,chi_sigma,num_res,param_num,...
                              ages,col_pos,exp_start,col_lev_corr,er_rate,tot_er_lim,sc_scheme,...
                              PR_Ca,PR_K,PR_Ti,PR_Fe,Pf,Var_mu,Var_UTh,decay,...
                              dd_step,hh_step,approx_meth,d_parts,h_parts)

% RandomWalkScarp.m applies Random Walk Monte-Carlo method to determine 
% the most probable rupture history: event ages, slips, erosion rate, 
% begining of exposure; or to fill solution space with rupture histories 
% which chi-squared estimator is equal to or smaller than entered
% chi-squared threshold.
%
% 'Search for the lowest chi-squared' mode
% Initial (or previouse) rupture history parameters are varied under 
% a normal distribution according to entered standard deviations.
% The chi-squared estimator of the fit of measured and modeled 36Cl 
% profiles is calculated for new rupture history. New rupture history is 
% accepted if ratio of the smalest collected to curent chi-squared 
% estimator is greater than rand^(exp(-exp(1))) (defined empirically).
%
% 'Chi-squared threshold' or 'Sigma confidence window' mode
% Initial (or previouse) rupture history is varied under a normal 
% distribution for each parameter according to entered standard deviations.
% The chi-squared estimator of the fit of measured and modeled 36Cl 
% profiles is calculated for new rupture history. New rupture history is 
% accepted if it's chi-squared estimator is qual to or smaller than entered
% chi-squared threshold. 


% input:

% 1) general input parameters

% DB - (database) structure which contains shielding factors and particle
% fluxes calculated at nodes of 3-dimentional mesh, as well as sample 
% coefficients and scaling factors (see DBmaker.m for details)
% sc_scheme - see BalcoScaling.m for details
% dd_step - mesh size of the depth perpendicular to scarp
% surface, cm (scalar)
% hh_step - mesh size of the position along scarp height, cm (scalar)
% approx_meth - approximation method of database, 'linear' or 'spline'
% d_parts - number of parts along the depth for sample partitioning (scalar)
% h_parts - number of parts along the position on the scarp for sample 

% 2) input parameters with error 

% PR_Ca, PR_K, PR_Ti and PR_Fe - production rates of 36Cl by high-energy
% neutron spallation on Ca, K, Ti and Fe including error, at/g yr
% format: [production_rate(at/g yr) error(at/g yr) 0]
% zero at third position means normal distribution (see get_rand.m)
% example: PR_Ca = [48.8 3.4 0] (Stone et al. 1996)
% Pf - production rate of epithermal neutrons at ground/air interface by
% high-energy neutrons including error, n/g yr
% format: [production_rate(at/g yr) error(at/g yr) 0]
% zero at third position means normal distribution (see get_rand.m)
% example: Pf = [626 63 0] (Phillips et al. 2001)
% decay - decay constant of 36Cl including error, 1/yr
% format: [decay_constant(1/yr) error(1/yr) 0]
% zero at third position means normal distribution (see get_rand.m)
% example: decay = [2.3028e-006 3.8252e-008 0] (http://www.nndc.bnl.gov/)

% 3) sought quantities

% The sampling space is formed by following dimentions: ages of events,
% colluvium positions, begining of exposure and erosion rate. The sampling
% space has 2n+2 dimentions, where n is number of events. Reference
% point correction is treated as sought quantities, but does not form
% sampling space. Initial value and variation (standard deviation) are 
% entered for each sought quantity (sampling space dimension) in following
% format: [initial_value standard deviation_value 0]
% zero at third position means normal distribution
%
% ages - n-by-3 matrix of event ages, yr (n is number of events)
% Example: ages = [1000 50 0; 500 25 0; 3000 150 0; 5000 250 0] means 
% Chronological order is unrequired.
% col_pos - n-by-3 matrix of colluvium positions before events, cm 
% (n is number of events)
% exp_start - 1-by-3 matrix of begining of exposure, yr
% er_rate - 1-by-3 matrix of erosion rate, cm/yr
% tot_er_lim - 1-by-2 matrix of total erosion limits, cm
% Example: tot_er_lim = [1 5] means that rupture histories with total
% erosion of scarp surface less than 1 cm and more than 5 cm will not be
% sampled(modeled).

% 4) input parameters defining chi-squared statistics
%
% chi_sigma - defines chi-squared threshold which is used to judge fit of
% modeled and measured 36Cl concentration curves. It requres following
% format: 
%         [chi-squared_value 1] - simply set a chi-squared threshold
%
%         [number_of_sigmas 2] - set a cofidence window(tolerance interval)
%         which is defined by number of standard deviations of standard
%         normal distribution (example: sigma cofidence window)
%                                         1         0.6827
%                                         2         0.9545
%                                         3         0.9973
%         chi-squared threshold value is calculated with chi-square inverse
%         cumulative distribution function
%         
%         [0 3] - search for the lowest chi-squared
%
% param_num - defines number of sought quantities (unknown parameters) for
% calculation of chi-squared values
% format: [usl 1] - number of sought quantities is defined as 2n+2, where n
%         is number of events. Parameter 'usl' is not in use
%         [m 2] - number of sought quantities is equal to 'm'
% num_res - number of successful simulations that will be collected after
% run of MonteCarloScarp.m

% output: see coments in the end of the code
 
% Written by Dmitry Tikhomirov
% Institut fuer Geologie, Universitt Bern
% tikhomirov@geo.unibe.ch, tikhomirovdmitry@gmail.com
% 2013-2016
%
% This program is free software; you can redistribute it and/or modify it 
% under a Creative Commons Attribution-NonCommercial-ShareAlike 3.0 
% Unported License (http://creativecommons.org/licenses/by-nc-sa/3.0/)


% degrees of freedom
eq_num= size(ages,1);
sam_num = length(DB.sam_36Clconc);
switch param_num(2)
    case 1
        param_num(1) = eq_num*2 + 2;
    case 2
end

deg_free = sam_num - param_num(1);

% define the chi2 threshold
if chi_sigma(2) == 1
    chi_max = chi_sigma(1);
elseif chi_sigma(2) == 2
    chi_max = chi2inv((2*normcdf(chi_sigma(1),0,1) - 1),deg_free)/deg_free;
elseif chi_sigma(2) == 3
    chi_max = 0; % code will search for lowest chi2
else
    error('chi_sigma(2) should be 1, 2 or 3')
end

% initialize a fresh random seed
stream = RandStream('mt19937ar','Seed',sum(100*clock));
RandStream.setGlobalStream(stream);
% 'mt19937ar' - standard gen
% 'mrg32k3a' - Combined Multiple Recursive gen
% 'mlfg6331_64' - Multiplicative Lagged Fibonacci gen

% start parallel computation with default profile
poolobj = gcp('nocreate');
if isempty(poolobj)
    poolobj = parpool;
end

% initialize the progress bar
wbar = waitbar(0,'Please wait...','Name','Starting calculation',...
               'CreateCancelBtn',...
               'setappdata(gcbf,''canceling'',1)');
set(wbar,'Units', 'characters', 'Position', [150 28 70 13]);
wax = findobj(wbar, 'type','axes');
tax = get(wax,'title');
set(tax,'FontSize',9)
set(tax,'HorizontalAlignment','left')
set(tax,'Units', 'characters','Position',[2 1.5])
wbut = findobj(wbar, 'style','pushbutton');
set(wbut,'String','Stop');
drawnow
setappdata(wbar,'canceling',0);
tic;

% initialize the initial point
col_lev_corr_b = Composite();
ages_b = Composite();
col_pos_b = Composite();
er_rate_b = Composite();
% get the number of workers (labs)
nworkers = length(er_rate_b);

exp_start_ages = [exp_start; ages];

for ii = 1:nworkers
    col_lev_corr_b{ii} = col_lev_corr;
    ages_b{ii} = exp_start_ages;
    col_pos_b{ii} = col_pos;
    er_rate_b{ii} = er_rate;
end

%!!!!!!!!!!!!!!!         SOME ADJUSTMENTS      !!!!!!!!!!!!!!!!!

% define how initial point for a worker of a parallel loop is chousen
% if init_point = 'best', the point with lowest chi-squared is chousen.
% This mode is better for fefinement of the result.
% if init_point = 'previous', the point from previous parallel loop is
% chousen. This mode is better for search of a result.
init_point = 'best'; % 'previous'

% define maximum number of results collected through parallel computation.
% smaller number allows you to check current progress more often (smoother
% progress bar), but makes calculation slower, due to more often data
% transition to and fro workers
% if init_point = 'best', smaller number is better for fefinement of the result.
% bigger number works vice versa. Bigger number is better for computer
% clusters when search of a result is done.
max_par_comp = 1000;

% define maximum number of tries if no successful simulations is collected
tot_max_tries = 1e4;

%!!!!!!!!!!!!!!!             END           !!!!!!!!!!!!!!!!!

% initialize counters and store varibles
tries = fix(min(num_res,max_par_comp)/nworkers) + 1;
tot_tries = 0;
n = 0;
hi_er_rate = 0;
mc_ages = [];
mc_col_pos = [];
mc_clc = [];
mc_chi = [];
mc_er_rate = [];
mc_PR = [];
mc_Var_db = [];
mc_decay = [];

% run the main cycle trough which a proper number of the results is collected 
for j = 1:4294967295

    % start the parallel mode
    spmd
        
    % initialize a composite counter and storage varibles 
    n_b = 0;
    hi_er_rate_b = 0;
    mc_chi_b = zeros(1,tries);
    mc_ages_b = zeros(eq_num + 1,tries);
    mc_col_pos_b = zeros(eq_num,tries);
    mc_clc_b = zeros(1,tries);
    mc_er_rate_b = zeros(1,tries);
    mc_PR_b = zeros(7,tries);
    mc_Var_db_b = zeros(sam_num,tries);
    mc_decay_b = zeros(1,tries);
    
    % run the random walk simulation cycle a supposed number of times
    for i = 1:tries

        % generate & check the colluvium level correction
        col_lev_corr_r = get_rand(col_lev_corr_b);
        while abs(col_lev_corr_r) > DB.max_coll_lev_corr
            col_lev_corr_r = get_rand(col_lev_corr_b);
        end
        
        % generate ages
        ages_r = get_rand(ages_b);
        % check the oldest age
        while max(ages_r) > DB.t_lim
               ages_r = get_rand(ages_b);
        end
        
        % generate coluvium positions
        col_pos_r = get_rand(col_pos_b);
        % check the cumulative slip
        stripe_top = max(DB.sam_top) - col_lev_corr_r;
        t_pos = round_from_zero(stripe_top,hh_step);
        while max(col_pos_r) > DB.tot_slip || max(col_pos_r) < t_pos
            col_pos_r = get_rand(col_pos_b);
        end
        
        % fix negative values and sort the ages and col_pos
        col_pos_r(col_pos_r < 0) = 0;
        ages_r(ages_r < 0) = 0;
        col_pos_r = sort(col_pos_r,'descend'); % [150 100 50]
        ages_r = sort(ages_r,'descend'); % [20000 15000 10000 5000]

        % generate an erosion rate
        er_rate_r = get_rand(er_rate_b);
        while er_rate_r < 0
            er_rate_r = get_rand(er_rate_b);
        end
        % check the net erosion & erosion rate
        isb = find(col_pos_r >= stripe_top,1,'last');
        
        er_age = ages_r(isb + 1);
        tot_er_r = er_age*er_rate_r/1000;
        if tot_er_r > min(DB.tot_er,tot_er_lim(2)) || tot_er_r < tot_er_lim(1)
            hi_er_rate_b = hi_er_rate_b + 1;
            continue
        end
        
        % generate and check production rates
        PR_Ca_r = get_rand(PR_Ca);
        while PR_Ca_r <= 0
            PR_Ca_r = get_rand(PR_Ca);
        end
        
        PR_K_r = get_rand(PR_K);
        while PR_K_r <= 0
            PR_K_r = get_rand(PR_K);
        end
        
        PR_Ti_r = get_rand(PR_Ti);
        while PR_Ti_r <= 0
            PR_Ti_r = get_rand(PR_Ti);
        end
        
        PR_Fe_r = get_rand(PR_Fe);
        while PR_Fe_r <= 0
            PR_Fe_r = get_rand(PR_Fe);
        end
        
        Pf_r = get_rand(Pf);
        while Pf_r <= 0
            Pf_r = get_rand(Pf);
        end
        
        Var_mu_r = get_rand(Var_mu);
        while Var_mu_r <= 0
            Var_mu_r = get_rand(Var_mu);
        end
        
        Var_UTh_r = get_rand(Var_UTh);
        while Var_UTh_r <= 0
            Var_UTh_r = get_rand(Var_UTh);
        end
        
        decay_r = get_rand(decay);
        while decay_r <= 0
            decay_r = get_rand(decay);
        end
        
        Var_db_r = get_rand(Var_db);
        while Var_db_r <= 0
            Var_db_r = get_rand(Var_db);
        end
        
        % simulate a rupture history of the fault scarp 
        model = ScarpSimulator(DB,Var_db_r,'simple',...
                              ages_r,col_pos_r,col_lev_corr_r,er_rate_r/1000,sc_scheme,...
                              PR_Ca_r,PR_K_r,PR_Ti_r,PR_Fe_r,Pf_r,Var_mu_r,Var_UTh_r,decay_r,...
                              dd_step,hh_step,approx_meth,d_parts,h_parts);
        
        Ntot = model.Ntot;
        Ntot_err = model.Ntot_err;
        chi = sum((((Ntot - DB.sam_36Clconc).^2)./(DB.sam_36Clerr.^2 + (Ntot_err.*DB.sam_36Clconc./Ntot).^2)))/deg_free;
        
        decission = 0;
        % check the chi2 value
        if chi_max > 0 && chi <= chi_max
            decission = 1;
        elseif chi_max == 0 && (n + n_b) == 0
            decission = 1;
        elseif chi_max == 0 && (n + n_b) ~= 0
            if n == 0
                chi_ratio = min(mc_chi_b(1:n_b))/chi;
            elseif n_b == 0
                chi_ratio = min(mc_chi)/chi;
            else
                chi_ratio = min(min(mc_chi),min(mc_chi_b(1:n_b)))/chi;
            end
            decission_distr = rand^(exp(-exp(1)));
            if chi_ratio > decission_distr
                decission = 1;
            end            
        end
        
        
        if decission == 1 || chi_max == 0
          n_b = n_b + 1;
          
          % save new good point
          mc_chi_b(n_b) = chi;
          mc_ages_b(:,n_b) = ages_r';
          mc_col_pos_b(:,n_b) = col_pos_r';
          mc_clc_b(n_b) = col_lev_corr_r;
          mc_er_rate_b(n_b) = er_rate_r;
          PR_r_b = [PR_Ca_r PR_K_r PR_Ti_r PR_Fe_r Pf_r Var_mu_r Var_UTh_r];
          mc_PR_b(:,n_b) = PR_r_b';
          mc_Var_db_b(:,n_b) = Var_db_r;
          mc_decay_b(n_b) = decay_r;
        end
          
        if decission == 1
          % set new good point as initial
          ages_b(:,1) = ages_r';
          col_pos_b(:,1) = col_pos_r';
          col_lev_corr_b(1) = col_lev_corr_r;
          er_rate_b(1) = er_rate_r;
        end       
    end
    
    % cut zeros in composite storage varibles 
    mc_chi_b = mc_chi_b(1:n_b);
    mc_ages_b = mc_ages_b(:,1:n_b);
    mc_col_pos_b = mc_col_pos_b(:,1:n_b);
    mc_clc_b = mc_clc_b(1:n_b);
    mc_er_rate_b = mc_er_rate_b(1:n_b);
    mc_PR_b = mc_PR_b(:,1:n_b);
    mc_Var_db_b = mc_Var_db_b(:,1:n_b);
    mc_decay_b = mc_decay_b(1:n_b);
    
    % stop parallel mode
    end
    % accemble the results from all workers (labs)
    for ii = 1:nworkers
        n = n + n_b{ii};
        hi_er_rate = hi_er_rate + hi_er_rate_b{ii};
        mc_chi = [mc_chi mc_chi_b{ii}];
        mc_ages = [mc_ages mc_ages_b{ii}];
        mc_col_pos = [mc_col_pos mc_col_pos_b{ii}];
        mc_clc = [mc_clc mc_clc_b{ii}];
        mc_er_rate = [mc_er_rate mc_er_rate_b{ii}];
        mc_PR = [mc_PR mc_PR_b{ii}];
        mc_Var_db = [mc_Var_db mc_Var_db_b{ii}];
        mc_decay = [mc_decay mc_decay_b{ii}];
    end
    % get the lowest found chi
    lowest_chi = min(mc_chi);
    
    % check the simulation progress
    tot_tries = tot_tries + tries*nworkers;
    
    if tot_tries >= tot_max_tries && n == 0
        oppa = 0;
        break
    end
    
    if n >= num_res
        oppa = 5;
        break
    end
    
    % calculate a theoretical number of tries to achieve the entered number
    % of successful simulatuions
    max_tries = fix(max_par_comp/nworkers) + 1;
    if n > 0
        sucs_part = n/tot_tries;
        theor_tries = round(num_res/sucs_part);
        tries = fix(theor_tries*0.1/nworkers) + 1;
        tries(tries > max_tries) = max_tries;
    elseif n == 0
        theor_tries = tot_max_tries;
        tries = max_tries;
    end
    
    % update progress bar
    progr = tot_tries/theor_tries;
    elap_time = toc;
    rem_time = elap_time*(1/progr - 1);
    waitbar(progr,wbar,...
            char(['Elapsed time:     ' sec2hhmmss(elap_time)], ['Remaining time: ' sec2hhmmss(rem_time)]...
                 , ['Successful simulations:  ' num2str(n)], ['Total simulations:            ' num2str(tot_tries)]...
                 , ['Lowest Chi-squared: ' num2str(lowest_chi)]));
    set(wbar,'Name',['Calculating...' num2str(floor(progr*100)) '%']);
    drawnow
    
    % check for the Cancel button is pressed
    if getappdata(wbar,'canceling')
        oppa = 0;
        break
    end
    
    if strcmp(init_point, 'best') && n ~= 0
        for ii = 1:nworkers
            [useless23,in_i] = min(mc_chi);
            in_i = in_i(1);
            col_lev_corr_b{ii} = [mc_clc(in_i)  col_lev_corr(2:3)];
            ages_b{ii} = [mc_ages(:,in_i)  exp_start_ages(:,2:3)];
            col_pos_b{ii} = [mc_col_pos(:,in_i)  col_pos(:,2:3)];
            er_rate_b{ii} = [mc_er_rate(in_i)  er_rate(2:3)];
        end
    end
    
end

% finish parallel computation
delete(poolobj);

% close the progress bar
delete(wbar)

out.tot_tries = tot_tries;

% check for unsuccessful simulation
if oppa == 0 && n == 0
    if tot_tries == hi_er_rate
        out.oppa = 1;
    else
        out.oppa = 0;
    end
    return
else
    out.oppa = 5;
end



% convert some of the results
mc_exp_start = mc_ages(1,:);
mc_ages(1,:) = [];

% statistic on the results
% results for minimal chi2
[min_chi,I_min_chi]  = min(mc_chi);
chi_ages = mc_ages(:,I_min_chi);
chi_exp_start = mc_exp_start(I_min_chi);
chi_col_pos = mc_col_pos(:,I_min_chi);
chi_clc = mc_clc(I_min_chi);
chi_er_rate = mc_er_rate(I_min_chi);
chi_PR = mc_PR(:,I_min_chi);
chi_Var_db = mc_Var_db(:,I_min_chi);
chi_decay = mc_decay(I_min_chi);

% mean values
mean_ages = mean(mc_ages,2);
mean_exp_start = mean(mc_exp_start);
mean_col_pos = mean(mc_col_pos,2);
mean_clc = mean(mc_clc);
mean_er_rate = mean(mc_er_rate);

% max values
max_ages = max(mc_ages,[],2);
max_exp_start = max(mc_exp_start);
max_col_pos = max(mc_col_pos,[],2);
max_clc = max(mc_clc);
max_er_rate = max(mc_er_rate);

% min values
min_ages = min(mc_ages,[],2);
min_exp_start = min(mc_exp_start);
min_col_pos = min(mc_col_pos,[],2);
min_clc = min(mc_clc);
min_er_rate = min(mc_er_rate);

% median values
median_ages = median(mc_ages,2);
median_exp_start = median(mc_exp_start);
median_col_pos = median(mc_col_pos,2);
median_clc = median(mc_clc);
median_er_rate = median(mc_er_rate);

% mode values
mode_ages = zeros(eq_num,1);
mode_col_pos = zeros(eq_num,1);
for ij = 1:eq_num
    mode_ages(ij) = cont_mode(mc_ages(ij,:));
    mode_col_pos(ij) = cont_mode(mc_col_pos(ij,:));
end
mode_exp_start = cont_mode(mc_exp_start);
mode_clc = cont_mode(mc_clc);
mode_er_rate = mode(mc_er_rate);
   
% get a concentration curve for the best fit
model = ScarpSimulator(DB,chi_Var_db,'simple',...
                      [chi_exp_start chi_ages'],chi_col_pos',chi_clc,chi_er_rate/1000,sc_scheme,...
                       chi_PR(1),chi_PR(2),chi_PR(3),chi_PR(4),chi_PR(5),chi_PR(6),chi_PR(7),chi_decay,...
                       dd_step,hh_step,approx_meth,d_parts,h_parts);              
N_chi = model.Ntot;
N_chi_err = model.Ntot_err;

% calculate AICc
AICc_add = 2*param_num(1)*sam_num/deg_free;
AICc = - sam_num*log(sum(((N_chi - DB.sam_36Clconc).^2))./sam_num) + AICc_add;
% calculate RMSw
RMSw = sqrt(sum(((N_chi - DB.sam_36Clconc).^2)./(DB.sam_36Clerr.^2 + N_chi_err.^2))/sam_num);

% form the output
out.suc_tries = n; % collected number of successful simulations
out.chi = mc_chi; % 1-by-n matrix of chi-squared values 
out.ages = mc_ages; % m-by-n matrix of ages, yr. m - number of events
out.exp_start = mc_exp_start; % 1-by-n matrix of beginings of exposure, yr
out.col_pos = mc_col_pos; % m-by-n matrix of colluvium positions before 
% events, cm. m - number of events
out.col_lev_cor = mc_clc; % 1-by-n matrix of reference point corrections, cm
out.er_rate = mc_er_rate; % 1-by-n matrix of erosion rates, cm/yr

% best fit solution
out.min_chi = min_chi; % chi-squared value
out.I_min_chi = I_min_chi; % matrix index of best fit solution
out.AICc = AICc; % Akaike information criterion
out.RMSw = RMSw; % Root mean square
out.N_chi = N_chi; % 1-by-s matrix of modeled 36Cl concentrations, where
% s - number of samples

out.chi_ages = chi_ages; % best fit ages
out.chi_exp_start = chi_exp_start; % best fit begining of exposure
out.chi_col_pos = chi_col_pos; % best fit colluvium positions
out.chi_clc = chi_clc; % best fit reference point correction
out.chi_er_rate = chi_er_rate; % best fit erosion rate
out.chi_PR = chi_PR; % best fit production rates

% mean values
out.mean_ages = mean_ages;
out.mean_exp_start = mean_exp_start;
out.mean_col_pos = mean_col_pos;
out.mean_clc = mean_clc;
out.mean_er_rate = mean_er_rate;

% maximum values
out.max_ages = max_ages;
out.max_exp_start = max_exp_start;
out.max_col_pos = max_col_pos;
out.max_clc = max_clc;
out.max_er_rate = max_er_rate;

% minimum values
out.min_ages = min_ages;
out.min_exp_start = min_exp_start;
out.min_col_pos = min_col_pos;
out.min_clc = min_clc;
out.min_er_rate = min_er_rate;

% median values
out.median_ages = median_ages;
out.median_exp_start = median_exp_start;
out.median_col_pos = median_col_pos;
out.median_clc = median_clc;
out.median_er_rate = median_er_rate;

% mode values
out.mode_ages = mode_ages;
out.mode_exp_start = mode_exp_start;
out.mode_col_pos = mode_col_pos;
out.mode_clc = mode_clc;
out.mode_er_rate = mode_er_rate;

end