function out = ScarpSimulator(DB,Var_db,out_type,...
                              ages,col_pos,col_lev_corr,er_rate,sc_scheme,...
                              PR_Ca,PR_K,PR_Ti,PR_Fe,Pf,Var_mu,Var_UTh,decay,...
                              dd_step,hh_step,approx_meth,d_parts,h_parts)

% ScarpSimulator.m models accumulation of 36Cl by footwall through rupture
% history defined by input
% simple output - 36Cl concentration in each sample and its error, at/g
% full output - 36Cl concentration in each sample and its error for each 
% production channel, at/g

% input:
% DB(database) - structure which contains shielding factors and particle
% fluxes calculated at nodes of 3-dimentional mesh, as well as sample 
% coefficients and scaling factors (see DBmaker.m for details)
% out_type - defines type of output. can be 'simple' or 'full'
% Var_db - 1-by-n matrix of variation coefficient representing errors of
% scarp shielding modeling and measurement (n is number of samples)
% ages - 1-by-(m+1) matrix of event ages and beginning of exposure, yr 
% (m = number of events)
% col_pos - 1-by-m matrix of colluvium positions before an event, cm
% (m = number of events)
% col_lev_cor - reference point correction, cm (scalar)
% er_rate - erosion rate, cm/yr (scalar)
% sc_scheme - see BalcoScaling.m for details
% PR_Ca, PR_K, PR_Ti and PR_Fe - production rates of 36Cl by high-energy
% neutron spallation on Ca, K, Ti and Fe respectively, at/g yr (scalar)
% Pf - production rate of epithermal neutrons at ground/air interface by
% high-energy neutrons, n/g yr (scalar)
% Var_mu - variation coefficient representing error of muon flux modeling
% (scalar)
% Var_UTh - variation coefficient representing error of production by 
% neutrons from U and Th (scalar)
% decay - decay constant of 36Cl, 1/yr (scalar)
% dd_step - mesh size of the depth perpendicular to scarp
% surface, cm (scalar)
% hh_step - mesh size of the position along scarp height, cm (scalar)
% approx_meth - approximation method of database, 'linear' or 'spline'
% d_parts - number of parts along the depth for sample partitioning (scalar)
% h_parts - number of parts along the position on the scarp for sample 
% partitioning (scalar)

% an example of input
% ages = [20000 15000 10000 5000]; 20000 - beginning of exposure
% 15000 10000 5000 - ages of eq.
% col_pos = [150 100 50]; colluvium positions before eq.
% col_lev_corr = 5;
% .....

% Written by Dmitry Tikhomirov
% Institut fuer Geologie, Universitt Bern
% tikhomirov@geo.unibe.ch, tikhomirovdmitry@gmail.com
% 2013-2016
%
% This program is free software; you can redistribute it and/or modify it 
% under a Creative Commons Attribution-NonCommercial-ShareAlike 3.0 
% Unported License (http://creativecommons.org/licenses/by-nc-sa/3.0/)

% let check input data & DB compatibility
if length(ages) ~= length(col_pos) + 1
    error('Size of matrix "ages" should be eaqual to size of matrix "col_pos" + 1')
end

if abs(col_lev_corr) > DB.max_coll_lev_corr
    error('Absolute value of colluvium level correction is too big for loaded database')
end

tot_slip = max(col_pos);
if tot_slip  > DB.tot_slip
    error('Entered total slip is too big for loaded database')
end

if strcmp(approx_meth,'linear') ~= 1 && strcmp(approx_meth,'cubic') ~= 1 ...
    && strcmp(approx_meth,'spline') ~= 1
    error('Approximation method should be "spline", "cubic" or "linear".')
end
   
dd_step(dd_step > DB.d_step) = DB.d_step;
hh_step(hh_step > DB.h_step) = DB.h_step; 

if max(ages) > DB.t_lim
    error('Oldest age is too big for loaded database')
end

stripe_top = max(DB.sam_top) - col_lev_corr;
isb = find(col_pos >= stripe_top,1,'last');
er_age = ages(isb + 1);
if er_age*er_rate > DB.tot_er
    error('Erosion rate is too high for loaded database')
end

% take chosen scaling scheme
switch sc_scheme
    case 'De'
        spall_scale = DB.Sc_De;
    case 'Du'
        spall_scale = DB.Sc_Du;
    case 'Li'
        spall_scale = DB.Sc_Li;
    case 'Lm'
        spall_scale = DB.Sc_Lm;
    case 'St'
        spall_scale = DB.Sc_St;
    otherwise
        error('Scaling scheme parameter should be "De", "Du", "Li", "Lm" or "St"');
end


% convert input data
col_pos = [col_pos 0];
zero_pos = -col_pos; % ex. [-150 -100 -50 0]
ages = [ages 0]; % ex. [20000 15000 10000 5000 0]
zero_pos = fliplr(zero_pos); % ex. [0 -50 -100 -150]
ages = fliplr(ages); % ex. [0 5000 10000 15000 20000]
% additional scaling factors
add_spall_scale = interp1(DB.time_scale,spall_scale,ages);
% number of time intervals
r = length(zero_pos);

% create matrix for accumulation
% values of variable "depth"
dep = max(DB.sam_thick);
dep = round_from_zero(dep,dd_step);
nn = dep/dd_step + 1;
dd = 0:dd_step:dep;
% values of variable "position on the scarp"
%stripe_top = max(DB.sam_top) - col_lev_corr;
t_pos = round_from_zero(stripe_top,hh_step);
mm_top = t_pos/hh_step;
stripe_bot = min(DB.sam_bot) - col_lev_corr;
b_pos = round_from_zero(stripe_bot,hh_step);
mm_bot = b_pos/hh_step;
mm = mm_top - mm_bot + 1;
hh = b_pos:hh_step:t_pos;
% and arrayed version
[hh2m, dd2m] = meshgrid(hh,dd);
% depth correction due to erosion
dd_ac = zeros(1,mm);

% and matrixes for accumulation
S_sp_ac = zeros(nn,mm);
PhiEB_ac = zeros(nn,mm);
Rnm_ac = zeros(nn,mm);
F_eth_ac = zeros(nn,mm);
F_th_ac = zeros(nn,mm);
 
% start eq event cycle 
for f = 1:r
    
    % time limits for this period w/o eq
    age_l = ages(f);
    age_h = ages(f+1);
    
    t_lf = fix(age_l/DB.t_step)+ 2;
    t_hf = fix(age_h/DB.t_step) + 1;
    
    p = t_hf - t_lf + 2;
    time = [age_l  DB.time_scale(t_lf:t_hf)  age_h];
    
    % scaling in time for this period w/o eq
    spall_sc_l = add_spall_scale(f);
    spall_sc_h = add_spall_scale(f + 1);
    spall_sc = [spall_sc_l  spall_scale(t_lf:t_hf)  spall_sc_h];
    
    % height of the scarp at this moment
    scarp_height = DB.scarp_height - col_lev_corr + zero_pos(f);
    
    % closest position of the scarp in DB
    k_l = fix((scarp_height - DB.hscarp(1))/DB.hscarp_step) + 1;
    k_l(k_l == length(DB.hscarp)) = k_l - 1;
    k_h = k_l + 1;
    
% create new DB-matrixes for our heigth of the scarp
    % some numbers to cut out a temporal DB-matrix of DB matrix
    hscarp_step_points = DB.hscarp_step/DB.h_step;
    m = length(DB.h) - hscarp_step_points;
    mi_l = hscarp_step_points + 1;
    mi_h = length(DB.h);
    % values of variables of temporal DB-matrix which will be used for
    % interpolation
    hscarp = DB.hscarp(k_l:k_h);
    h = DB.h(1:m) - DB.hscarp_step*(length(DB.hscarp) - k_h);
    d = DB.d;
    % same variables in array mode
    [h3m, d3m, hscarp3m] = meshgrid(h,d,hscarp);
    [h2m, d2m, hscarp2m] = meshgrid(h,d,scarp_height);
    % here is temporal DB-matrix which will be used for interpolation
    Temp_db(:,:,1) = DB.S_sp(:,mi_l:mi_h,k_l);
    Temp_db(:,:,2) = DB.S_sp(:,1:m,k_h);
    % and finaly new DB-matrix for our heigth of the scarp
    S_sp_db = interp3(h3m,d3m,hscarp3m,Temp_db,h2m,d2m,hscarp2m);
    % that was spallation shielding factors
    % lets find same matrixes for
    % fast muons - PhiEB
    Temp_db(:,:,1) = DB.PhiEB(:,mi_l:mi_h,k_l);
    Temp_db(:,:,2) = DB.PhiEB(:,1:m,k_h);
    PhiEB_db = interp3(h3m,d3m,hscarp3m,Temp_db,h2m,d2m,hscarp2m);
    % stoping rate of negative muons
    Temp_db(:,:,1) = DB.Rnm(:,mi_l:mi_h,k_l);
    Temp_db(:,:,2) = DB.Rnm(:,1:m,k_h);
    Rnm_db = interp3(h3m,d3m,hscarp3m,Temp_db,h2m,d2m,hscarp2m);   
    % epithermal neutron flux
    Temp_db(:,:,1) = DB.F_eth(:,mi_l:mi_h,k_l);
    Temp_db(:,:,2) = DB.F_eth(:,1:m,k_h);
    F_eth_db = interp3(h3m,d3m,hscarp3m,Temp_db,h2m,d2m,hscarp2m);
    % and thermal neutron flux
    Temp_db(:,:,1) = DB.F_th(:,mi_l:mi_h,k_l);
    Temp_db(:,:,2) = DB.F_th(:,1:m,k_h);
    F_th_db = interp3(h3m,d3m,hscarp3m,Temp_db,h2m,d2m,hscarp2m);
    
    % position of sample stripe
    hh_span = hh + zero_pos(f);
    
    % start accumulation cycle during period w/o eq
    for g = 1:p
        
        % time factor
        T = (exp(-time(g)*decay) - exp(-time(g+1)*decay))/decay;
        % spallation scaling factor at this moment in time
        Ssc_span = (spall_sc(g) + spall_sc(g + 1))/2;
        % eroded layer
        d_er = er_rate*(time(g) + time(g+1))/2;
        % find points above and below
        above = sign(hh_span);
        above(above < 0) = 0;
        below = ones(size(above)) - above;
        % depth of the sample's tops
        dd_er = below.*dd_ac + above.*d_er;
        % arrayed depth & position
        [hh_span2m, dd2m] = meshgrid(hh_span,dd);
        dd_span2m = bsxfun(@plus,dd2m,dd_er);
        % spallation by neutrons
        S_sp_span = interp2(h2m,d2m,S_sp_db,hh_span2m,dd_span2m,approx_meth).*Ssc_span.*T;
        % fast muons - PhiEB
        PhiEB_span = interp2(h2m,d2m,PhiEB_db,hh_span2m,dd_span2m,approx_meth).*T;
        % stoping rate of negative muons
        Rnm_span = interp2(h2m,d2m,Rnm_db,hh_span2m,dd_span2m,approx_meth).*T;
        % epithermal neutron flux
        F_eth_span = interp2(h2m,d2m,F_eth_db,hh_span2m,dd_span2m,approx_meth).*Ssc_span.*T;
        % thermal neutron flux
        F_th_span = interp2(h2m,d2m,F_th_db,hh_span2m,dd_span2m,approx_meth).*Ssc_span.*T;
        % let's save for next turn, so we accumulate stuff
        S_sp_ac = S_sp_ac + S_sp_span;
        PhiEB_ac = PhiEB_ac + PhiEB_span;
        Rnm_ac = Rnm_ac + Rnm_span;
        F_eth_ac = F_eth_ac + F_eth_span;
        F_th_ac = F_th_ac + F_th_span;
              
    end
    % depth of the sample's tops for next turn
    dd_ac = dd_er;
end
%  allocate variables for concentrations accumulated in each sample
sam_num = length(DB.sam_top);
NspCa = zeros(1,sam_num);
NspK = zeros(1,sam_num);
NspTi = zeros(1,sam_num);
NspFe = zeros(1,sam_num);
Nfm = zeros(1,sam_num);
Nnm = zeros(1,sam_num);
Neth = zeros(1,sam_num);
Nth = zeros(1,sam_num);
Nnfm = zeros(1,sam_num);
Nnnm = zeros(1,sam_num);
NnUTh = zeros(1,sam_num);
Ntot = zeros(1,sam_num);

% and their errors due to error in concentration of parent elements
NspCa_err = zeros(1,sam_num);
NspK_err = zeros(1,sam_num);
NspTi_err = zeros(1,sam_num);
NspFe_err = zeros(1,sam_num);
Nfm_err = zeros(1,sam_num);
Nnm_err = zeros(1,sam_num);
Neth_err = zeros(1,sam_num);
Nth_err = zeros(1,sam_num);
Nnfm_err = zeros(1,sam_num);
Nnnm_err = zeros(1,sam_num);
NnUTh_err = zeros(1,sam_num);
Ntot_err = zeros(1,sam_num);



 for num = 1:sam_num;
     samh_step = (DB.sam_top(num) - DB.sam_bot(num))/h_parts;
     samd_step = DB.sam_thick(num)/d_parts;
     samh = (DB.sam_bot(num) + samh_step/2):samh_step:(DB.sam_bot(num) + samh_step*(h_parts - 1/2));
     samh = samh - col_lev_corr;
     samd = (samd_step/2):samd_step:(samd_step*(d_parts - 1/2));
     [samh2m, samd2m] = meshgrid(samh,samd);
     % spallation by high-energy neutrons
     Temp_array = interp2(hh2m,dd2m,S_sp_ac,samh2m,samd2m,approx_meth);
     S_sp_sam = mean(mean(Temp_array));
     NspCa(num) = Var_db(num)*S_sp_sam*PR_Ca*DB.sam_spCa(num);
     NspK(num) = Var_db(num)*S_sp_sam*PR_K*DB.sam_spK(num);
     NspTi(num) = Var_db(num)*S_sp_sam*PR_Ti*DB.sam_spTi(num);
     NspFe(num) = Var_db(num)*S_sp_sam*PR_Fe*DB.sam_spFe(num);
     NspCa_err(num) = Var_db(num)*S_sp_sam*PR_Ca*DB.sam_spCa_err(num);
     NspK_err(num) = Var_db(num)*S_sp_sam*PR_K*DB.sam_spK_err(num);
     NspTi_err(num) = Var_db(num)*S_sp_sam*PR_Ti*DB.sam_spTi_err(num);
     NspFe_err(num) = Var_db(num)*S_sp_sam*PR_Fe*DB.sam_spFe_err(num);
     % fast muons & neutrons produced by them
     Temp_array = interp2(hh2m,dd2m,PhiEB_ac,samh2m,samd2m,approx_meth);
     PhiEB_sam = mean(mean(Temp_array));
     Nfm(num) = Var_db(num)*PhiEB_sam*Var_mu*DB.sam_fm(num);
     Nnfm(num) = Var_db(num)*PhiEB_sam*Var_mu*DB.sam_nfm(num);
     Nfm_err(num) = Var_db(num)*PhiEB_sam*Var_mu*DB.sam_fm_err(num);
     Nnfm_err(num) = Var_db(num)*PhiEB_sam*Var_mu*DB.sam_nfm_err(num);
     % negative muons & neutrons produced by them
     Temp_array = interp2(hh2m,dd2m,Rnm_ac,samh2m,samd2m,approx_meth);
     Rnm_sam = mean(mean(Temp_array));
     Nnm(num) = Var_db(num)*Rnm_sam*Var_mu*DB.sam_nm(num);
     Nnnm(num) = Var_db(num)*Rnm_sam*Var_mu*DB.sam_nnm(num);
     Nnm_err(num) = Var_db(num)*Rnm_sam*Var_mu*DB.sam_nm_err(num);
     Nnnm_err(num) = Var_db(num)*Rnm_sam*Var_mu*DB.sam_nnm_err(num);
     % epithermal neutrons
     Temp_array = interp2(hh2m,dd2m,F_eth_ac,samh2m,samd2m,approx_meth);
     F_eth_sam = mean(mean(Temp_array));
     Neth(num) = Var_db(num)*F_eth_sam*Pf*DB.sam_eth(num);
     Neth_err(num) = Var_db(num)*F_eth_sam*Pf*DB.sam_eth_err(num);
     % thermal neutrons
     Temp_array = interp2(hh2m,dd2m,F_th_ac,samh2m,samd2m,approx_meth);
     F_th_sam = mean(mean(Temp_array));
     Nth(num) = Var_db(num)*F_th_sam*Pf*DB.sam_th(num);
     Nth_err(num) = Var_db(num)*F_th_sam*Pf*DB.sam_th_err(num);
     % thermal netrons from U % Th decay
     NnUTh(num) = Var_db(num)*DB.P_UTh(num)*Var_UTh*(1 - exp( - max(ages)*decay))/decay;
     NnUTh_err(num) = Var_db(num)*DB.P_UTh_err(num)*Var_UTh*(1 - exp( - max(ages)*decay))/decay;
     % and total
     Ntot(num) = NspCa(num) + NspK(num) + NspTi(num) + NspFe(num) +...
                 Nfm(num) + Nnfm(num) + Nnm(num) + Nnnm(num) +...
                 Neth(num) + Nth(num) + NnUTh(num);
     Ntot_err(num) = sqrt(NspCa_err(num).^2 + NspK_err(num).^2 + NspTi_err(num).^2 + NspFe_err(num).^2 +...
                 Nfm_err(num).^2 + Nnfm_err(num).^2 + Nnm_err(num).^2 + Nnnm_err(num).^2 +...
                 Neth_err(num).^2 + Nth_err(num).^2 + NnUTh_err(num).^2);
 end

if strcmp(out_type,'simple')
    out.Ntot = Ntot.*1e-5;
    out.Ntot_err = Ntot_err.*1e-5;
elseif strcmp(out_type,'full')
    out.Ntot = [NspCa' NspK' NspTi' NspFe' Nfm' Nnfm' Nnm' Nnnm' Neth' Nth' NnUTh'].*1e-5;
    out.Ntot_err = [NspCa_err' NspK_err' NspTi_err' NspFe_err' Nfm_err' Nnfm_err' Nnm_err' Nnnm_err' Neth_err' Nth_err' NnUTh_err'].*1e-5;
else
    error('Output type should be "simple" or "full".')
end

 end

 