function out = ThermEpithermNeutronCoef(Lambda_f,soil,wat_perc,nucl_data)

% calculates coefficients and attenuation lengths of thermal and 
% epithermal neutron fluxes formulae:
%      epithermal flux = Pf0 * ( Fi1eth_soil.*exp(-x./Lambda_f) + Ceth_soil.*exp(-x./Leth_soil))
%      thermal flux    = Pf0 * ( Fifth_soil.*exp(-x./Lambda_f) + FiLth_soil.*exp(-x./eth_soil) + Cth_soil.*exp(-x./Lth_soil))
%
% output: 
% [Fi1eth_soil  Ceth_soil  Lambda_f  Leth_soil  Fifth_soil  FiLth_soil   Cth_soil  Lambda_f  Leth_soil  Lth_soil]
%
% input: 
% Lambda_f - attenuation length of high-energy neutrons in the soil.
% soil - 18-by-1 matrix containing chemical composition of dry soil
% in following order: Cl, C, O, Na, Mg, Al, Si, P, K, Ca Ti, Mg,
% Fe, B, Sm, Gd, U, Th, mass %
% wat_perc - average content of water in the soil, mass %
% nucl_data - nuclear physical constants and factors from nucl_data.mat

% References:
% Alfimov, V., and Ivy-Ochs, S., 2009. How well do we understand 
% production of 36Cl in limestone and dolomite? Quaternary Geochronology, 
% 4 (6), 462474.

% Written by Dmitry Tikhomirov
% Institut fuer Geologie, Universitt Bern
% tikhomirov@geo.unibe.ch, tikhomirovdmitry@gmail.com
% 2013-2016
%
% This program is free software; you can redistribute it and/or modify it 
% under a Creative Commons Attribution-NonCommercial-ShareAlike 3.0 
% Unported License (http://creativecommons.org/licenses/by-nc-sa/3.0/)

N_a = 0.6022; % *10^24 because cross-sections are in barns

at_m = nucl_data(:,1)';
log_dec = nucl_data(:,2)';
sigma_sc = nucl_data(:,3)';
sigma_th = nucl_data(:,4)';
I_a = nucl_data(:,5)';


air = [0 0.2323 zeros(1,17) 0.7549 0.0128];
water = [0 0.889 zeros(1,16) 0.11 0 0];

soil = soil./sum(soil);
soil = soil.*(1 - wat_perc*0.01) + water.*wat_perc*0.01;

N_soil = soil./at_m;
N_air = air./at_m;

at_m_soil = 1/sum(N_soil);
at_m_air = 1/sum(N_air);


Sigma_sc_soil = sum(sigma_sc.*N_soil.*N_a);
Sigma_sc_air = sum(sigma_sc.*N_air.*N_a);

Dsoil = 1/(3*Sigma_sc_soil*(1-2/(3*at_m_soil)));
Dair = 1/(3*Sigma_sc_air*(1-2/(3*at_m_air)));

log_dec_soil = sum(log_dec.*sigma_sc.*N_soil)/sum(sigma_sc.*N_soil);
log_dec_air = sum(log_dec.*sigma_sc.*N_air)/sum(sigma_sc.*N_air);

Ieff_soil = sum(I_a.*N_soil.*N_a);
Ieff_air = sum(I_a.*N_air.*N_a);

% Epitermal neutrons
Lambda_eth_soil = 1/(log_dec_soil*(Ieff_soil + Sigma_sc_soil));
Lambda_eth_air = 1/(log_dec_air*(Ieff_air + Sigma_sc_air));

Sigma_eth_soil = 1/Lambda_eth_soil;
Sigma_eth_air = 1/Lambda_eth_air;
% Epithermal attenuation length
Leth_soil = sqrt(Dsoil/Sigma_eth_soil);
Leth_air = sqrt(Dair/Sigma_eth_air);

Reth = sqrt(at_m_soil/at_m_air);
% Epithermal coef 1
Fi1eth_soil = Reth/(Sigma_eth_soil - Dsoil/Lambda_f^2);
Fi1eth_air = 1/(Sigma_eth_air - Dair/Lambda_f^2);
% Epithermal coef 2
Ceth_soil = ((Fi1eth_air-Fi1eth_soil)*Dair/Leth_air + ...
    (Fi1eth_air*Dair - Fi1eth_soil*Dsoil)/Lambda_f)/...
    (Dair/Leth_air + Dsoil/Leth_soil);
Ceth_air = ((Fi1eth_soil - Fi1eth_air)*Dsoil/Leth_soil + ...
    (Fi1eth_air*Dair - Fi1eth_soil*Dsoil)/Lambda_f)/...
    (Dair/Leth_air + Dsoil/Leth_soil);

% Thermal neutrons
p_soil = exp(-Ieff_soil/(log_dec_soil*Sigma_sc_soil));
p_air = exp(-Ieff_air/(log_dec_air*Sigma_sc_air));

Lambda_th_soil = 1/sum(sigma_th.*N_soil.*N_a);
Lambda_th_air = 1/sum(sigma_th.*N_air.*N_a);

Sigma_th_soil = 1/Lambda_th_soil;
Sigma_th_air = 1/Lambda_th_air;
% Thermal attenuation length
Lth_soil = sqrt(Dsoil/Sigma_th_soil);
Lth_air = sqrt(Dair/Sigma_th_air);
% Thermal coef 1
Fifth_soil = p_soil*Fi1eth_soil*Sigma_eth_soil/...
    (Sigma_th_soil - Dsoil/Lambda_f^2);
Fifth_air = p_air*Fi1eth_air*Sigma_eth_air/...
    (Sigma_th_air - Dair/Lambda_f^2);
% Thermal coef 2
FiLth_soil = p_soil*Ceth_soil*Sigma_eth_soil/...
    (Sigma_th_soil - Dsoil/Leth_soil^2);
FiLth_air = p_air*Ceth_air*Sigma_eth_air/...
    (Sigma_th_air - Dair/Leth_air^2);

C1th = (Fifth_air*Dair - Fifth_soil*Dsoil)/Lambda_f -...
    (FiLth_air*Dair/Leth_air + FiLth_soil*Dsoil/Leth_soil);

DeltaFith = Fifth_soil - Fifth_air + FiLth_soil - FiLth_air;
% Thermal coef 3
Cth_soil = (C1th - DeltaFith*Dair/Lth_air)/(Dsoil/Lth_soil + Dair/Lth_air);
Cth_air = (C1th + DeltaFith*Dsoil/Lth_soil)/(Dsoil/Lth_soil + Dair/Lth_air);


% output
Epth_coef = [Fi1eth_soil  Ceth_soil  Lambda_f  Leth_soil];
Th_coef = [Fifth_soil  FiLth_soil   Cth_soil  Lambda_f  Leth_soil  Lth_soil];
out = [Epth_coef Th_coef];
end