function out = muon_flux(theta,d,P,m_u)
% 
% Modified by Dmitry Tikhomirov, 2014.
%
% Originally P_mu_total.m
% Written by Greg Balco -- UW Cosmogenic Nuclide Lab
% balcs@u.washington.edu
% March, 2006
% Part of the CRONUS-Earth online calculators: 
%      http://hess.ess.washington.edu/math
%
% Copyright 2001-2007, University of Washington
% All rights reserved
% Developed in part with funding from the National Science Foundation.
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License, version 2,
% as published by the Free Software Foundation (www.fsf.org).

Nlin = 180/m_u;
Ncol = 90/m_u;

% figure vertical depth

z = d.*sin(theta);

z(z > 2e5) = 2e5;

% figure the atmospheric depth in g/cm2

H = (1013.25 - P).*1.019716;

% find the vertical flux at SLHL

phi_vert_slhl = Phi_v(z);

phi_vert_site = z; % just to book matrix)

% find the flux of vertical muons at site 
for j = 1:Ncol
    for k = 1:Nlin
        % integrate
        % ends at 200,001 g/cm2 to avoid being asked for an zero
        % range of integration -- 
        % get integration tolerance -- want relative tolerance around
        % 1 part in 10^4. 
        tol = phi_vert_slhl(k,j) * 1e-4;
        temp = integral(@(x) Rv0(x).*exp(H./LZ(x)),z(k,j),(2e5+1),'AbsTol',tol);
        % second variable assignment here to preserve fcnt if needed
        phi_vert_site(k,j) = temp;
    end    
end

   
% invariant flux at 2e5 g/cm2 depth - constant of integration
% calculated using commented-out formula above
phi_200k = Phi_v(2e5);
phi_vert_site = phi_vert_site + phi_200k;

% find the total flux of muons at site

% angular distribution exponent
nofz = 3.21 - 0.297.*log((z+H)./100 + 42) + 1.21e-5.*(z+H);

phi_sec = phi_vert_site.*((sin(theta)).^nofz).*cos(theta);

% that was in muons/cm2/s
% convert to muons/cm2/yr

phi = phi_sec*60*60*24*365.25;

out = phi;
end


function out = Phi_v(z)

% this subfunction returns the flux of vertically traveling muons
% as a function of depth z at sea level and high latitude.

a = 258.5*(100.^2.66);
b = 75*(100.^1.66);

out = (a./((z+21000).*(((z+1000).^1.66) + b))).*exp(-5.5e-6 .* z);

% The above expression is only good to 2e5 g/cm2. We don't ever consider production
% below that depth. The full-depth scheme appears in the comments below.
% ------ begin full-depth flux equations -------
%phiz_1 = (a./((z+21000).*(((z+1000).^1.66) + b))).*exp(-5.5e-6 .* z);
%phiz_2 = 1.82e-6.*((121100./z).^2).*exp(-z./121100) + 2.84e-13;
%out(find(z<200000)) = phiz_1(find(z<200000));
%out(find(z>=200000)) = phiz_2(find(z>=200000));
% ------ end full-depth flux equations -------

end


function out = Rv0(z)

% this subfunction returns the stopping rate of vertically traveling muons
% as a function of depth z at sea level and high latitude.

a = exp(-5.5e-6.*z);
b = z + 21000;
c = (z + 1000).^1.66 + 1.567e5;
dadz = -5.5e-6 .* exp(-5.5e-6.*z);
dbdz = 1;
dcdz = 1.66.*(z + 1000).^0.66;

out = -5.401e7 .* (b.*c.*dadz - a.*(c.*dbdz + b.*dcdz))./(b.^2 .* c.^2);

% full depth calculation appears in comments below
%R_1 = -5.401e7 .* (b.*c.*dadz - a.*(c.*dbdz + b.*dcdz))./(b.^2 .* c.^2);
%f = (121100./z).^2;
%g = exp(-z./121100);
%dfdz = (-2.*(121100.^2))./(z.^3);
%dgdz = -exp(-z./121100)./121100;
%R_2 = -1.82e-6.*(g.*dfdz + f.*dgdz);
%out(find(z<200000)) = R_1(find(z<200000));
%out(find(z>=200000)) = R_2(find(z>=200000));

end


function out = LZ(z)

% this subfunction returns the effective atmospheric attenuation length for
% muons of range Z

% Written by Greg Balco -- UW Cosmogenic Nuclide Lab
% balcs@u.washington.edu
% March, 2006
% Part of the CRONUS-Earth online calculators: 
%      http://hess.ess.washington.edu/math
%
% Copyright 2001-2007, University of Washington
% All rights reserved
% Developed in part with funding from the National Science Foundation.
%
% This program is free software; you can redistribute it and/or modify
% it under the terms of the GNU General Public License, version 2,
% as published by the Free Software Foundation (www.fsf.org).

% define range/momentum relation
% table for muons in standard rock in Groom and others 2001

data = [4.704e1 8.516e-1
    5.616e1 1.542e0
    6.802e1 2.866e0
    8.509e1 5.698e0
    1.003e2 9.145e0
    1.527e2 2.676e1
    1.764e2 3.696e1
    2.218e2 5.879e1
    2.868e2 9.332e1
    3.917e2 1.524e2
    4.945e2 2.115e2
    8.995e2 4.418e2
    1.101e3 5.534e2
    1.502e3 7.712e2
    2.103e3 1.088e3
    3.104e3 1.599e3
    4.104e3 2.095e3
    8.105e3 3.998e3
    1.011e4 4.920e3
    1.411e4 6.724e3
    2.011e4 9.360e3
    3.011e4 1.362e4
    4.011e4 1.776e4
    8.011e4 3.343e4
    1.001e5 4.084e4
    1.401e5 5.495e4
    2.001e5 7.459e4
    3.001e5 1.040e5
    4.001e5 1.302e5
    8.001e5 2.129e5];

% ignore ranges bigger than 2e5 g/cm2
%    1.000e6 2.453e5
%    1.4e6   2.990e5
%    2.0e6   3.616e5
%    3.0e6   4.384e5
%    4.0e6   4.957e5
%    8.0e6   6.400e5
%    1.0e7   6.877e5
%    1.4e7   7.603e5
%    2.0e7   8.379e5
%    3.0e7   9.264e5
%    4.0e7   9.894e5
%    8.0e7   1.141e6
%    1.0e8   1.189e6];

% units are range in g cm-2 (column 2)
% momentum in MeV/c (column 1)

% deal with zero situation

too_low = find(z < 1);
z(too_low) = ones(size(too_low));

% obtain momenta
% use log-linear interpolation

P_MeVc = exp(interp1q(log(data(:,2)),log(data(:,1)),log(z')))';

% obtain attenuation lengths

out = 263 + 150 .* (P_MeVc./1000);

end